package com.reign.gcld.juben.service;

import com.reign.framework.json.JsonBuilder;
import com.reign.framework.json.JsonDocument;
import com.reign.framework.json.State;
import com.reign.framework.netty.servlet.Request;
import com.reign.gcld.battle.common.BattleArmy;
import com.reign.gcld.battle.common.BattleDrop;
import com.reign.gcld.battle.common.BattleScheduler;
import com.reign.gcld.battle.common.ErrorSceneLog;
import com.reign.gcld.battle.common.Terrain;
import com.reign.gcld.battle.common.UpdateExp;
import com.reign.gcld.battle.dao.IPlayerArmyDao;
import com.reign.gcld.battle.dao.IScenarioNpcDao;
import com.reign.gcld.battle.domain.PlayerArmy;
import com.reign.gcld.battle.domain.PlayerBattleAttribute;
import com.reign.gcld.battle.domain.ScenarioNpc;
import com.reign.gcld.battle.scene.BaseInfo;
import com.reign.gcld.battle.scene.Battle;
import com.reign.gcld.battle.scene.BattleAttacker;
import com.reign.gcld.battle.scene.Builder;
import com.reign.gcld.battle.scene.BuilderFactory;
import com.reign.gcld.battle.scene.CampArmy;
import com.reign.gcld.battle.service.BattleDataCache;
import com.reign.gcld.battle.service.IBattleService;
import com.reign.gcld.battle.service.NewBattleManager;
import com.reign.gcld.chat.common.ChatLink;
import com.reign.gcld.civiltrick.trick.TrickFactory;
import com.reign.gcld.common.ColorUtil;
import com.reign.gcld.common.Constants;
import com.reign.gcld.common.IDataGetter;
import com.reign.gcld.common.LocalMessages;
import com.reign.gcld.common.Players;
import com.reign.gcld.common.PushCommand;
import com.reign.gcld.common.WorldDramaTimesCache;
import com.reign.gcld.common.log.CommonLog;
import com.reign.gcld.common.log.Logger;
import com.reign.gcld.common.util.SymbolUtil;
import com.reign.gcld.common.util.WebUtil;
import com.reign.gcld.common.web.GcldInitManager;
import com.reign.gcld.general.dao.IPlayerGeneralCivilDao;
import com.reign.gcld.general.dao.IPlayerGeneralMilitaryDao;
import com.reign.gcld.general.domain.PlayerGeneralCivil;
import com.reign.gcld.general.domain.PlayerGeneralMilitary;
import com.reign.gcld.general.dto.GeneralMoveDto;
import com.reign.gcld.general.service.IGeneralService;
import com.reign.gcld.job.service.IJobService;
import com.reign.gcld.juben.common.IJuBenDataCache;
import com.reign.gcld.juben.common.JuBenCityDto;
import com.reign.gcld.juben.common.JuBenDto;
import com.reign.gcld.juben.common.JubenConstans;
import com.reign.gcld.juben.common.MiniTimeWinInfo;
import com.reign.gcld.juben.common.TrickDto;
import com.reign.gcld.juben.dao.IPlayerScenarioCityDao;
import com.reign.gcld.juben.dao.IPlayerScenarioDao;
import com.reign.gcld.juben.dao.IScenarioInfoDao;
import com.reign.gcld.juben.domain.PlayerScenario;
import com.reign.gcld.juben.domain.PlayerScenarioCity;
import com.reign.gcld.juben.domain.ScenarioInfo;
import com.reign.gcld.log.LogUtil;
import com.reign.gcld.log.TimerLogger;
import com.reign.gcld.player.common.AddExpInfo;
import com.reign.gcld.player.dao.IPlayerAttributeDao;
import com.reign.gcld.player.dao.IPlayerDao;
import com.reign.gcld.player.dao.IPlayerResourceDao;
import com.reign.gcld.player.domain.Player;
import com.reign.gcld.player.domain.PlayerAttribute;
import com.reign.gcld.player.domain.PlayerResource;
import com.reign.gcld.player.dto.PlayerDto;
import com.reign.gcld.player.dto.ResourceDto;
import com.reign.gcld.player.service.IPlayerService;
import com.reign.gcld.scenario.common.ScenarioEvent;
import com.reign.gcld.scenario.common.ScenarioEventJsonBuilder;
import com.reign.gcld.scenario.common.choice.ScenarioChoice;
import com.reign.gcld.scenario.message.ScenarioEventMessageHelper;
import com.reign.gcld.scenario.service.ScenarioEventManager;
import com.reign.gcld.sdata.cache.ArmiesCache;
import com.reign.gcld.sdata.cache.EquipCache;
import com.reign.gcld.sdata.cache.GeneralCache;
import com.reign.gcld.sdata.cache.ItemsCache;
import com.reign.gcld.sdata.cache.SoloCityCache;
import com.reign.gcld.sdata.cache.SoloDramaCache;
import com.reign.gcld.sdata.cache.SoloEventCache;
import com.reign.gcld.sdata.cache.SoloRewardCache;
import com.reign.gcld.sdata.cache.SoloRoadCache;
import com.reign.gcld.sdata.cache.StratagemCache;
import com.reign.gcld.sdata.cache.TroopCache;
import com.reign.gcld.sdata.cache.WdSjpDramaCache;
import com.reign.gcld.sdata.domain.Armies;
import com.reign.gcld.sdata.domain.Army;
import com.reign.gcld.sdata.domain.EquipCoordinates;
import com.reign.gcld.sdata.domain.EquipProset;
import com.reign.gcld.sdata.domain.General;
import com.reign.gcld.sdata.domain.Items;
import com.reign.gcld.sdata.domain.SoloCity;
import com.reign.gcld.sdata.domain.SoloDrama;
import com.reign.gcld.sdata.domain.SoloEvent;
import com.reign.gcld.sdata.domain.SoloReward;
import com.reign.gcld.sdata.domain.SoloRoad;
import com.reign.gcld.sdata.domain.Stratagem;
import com.reign.gcld.sdata.domain.Troop;
import com.reign.gcld.sdata.domain.TroopConscribe;
import com.reign.gcld.sdata.domain.WdSjp;
import com.reign.gcld.sdata.domain.WdSjpDrama;
import com.reign.gcld.store.dao.IStoreHouseDao;
import com.reign.gcld.store.dao.IStoreHouseSellDao;
import com.reign.gcld.store.domain.StoreHouse;
import com.reign.gcld.store.domain.StoreHouseSell;
import com.reign.gcld.store.service.IStoreHouseService;
import com.reign.gcld.store.service.StoreHouseService;
import com.reign.gcld.system.domain.ServerTime;
import com.reign.gcld.team.common.GeneralInfo;
import com.reign.gcld.team.common.Team;
import com.reign.gcld.team.common.TeamMember;
import com.reign.gcld.team.service.OperationResult;
import com.reign.gcld.team.service.TeamManager;
import com.reign.gcld.tech.domain.PlayerTech;
import com.reign.gcld.world.common.CityEventManager;
import com.reign.gcld.world.common.WorldCityCommon;
import com.reign.gcld.world.service.CityService;
import com.reign.util.CDUtil;
import com.reign.util.MessageFormatter;
import com.reign.util.Tuple;
import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Iterator;
import java.util.LinkedList;
import java.util.List;
import java.util.Map;
import java.util.Set;
import java.util.concurrent.ConcurrentHashMap;
import java.util.concurrent.CopyOnWriteArraySet;
import java.util.concurrent.atomic.AtomicInteger;
import org.apache.commons.lang.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.springframework.transaction.annotation.Transactional;

@Component("juBenService")
public class JuBenService implements IJuBenService {
   private static final Logger errorLog = CommonLog.getLog(JuBenService.class);
   private static final Logger timeLog = new TimerLogger();
   private static final Logger timerLog = new TimerLogger();
   public static final Map<String, MiniTimeWinInfo> miniWinTime = new ConcurrentHashMap();
   public static AtomicInteger scenarioNpcVId = new AtomicInteger();
   @Autowired
   private IDataGetter dataGetter;
   @Autowired
   private IPlayerScenarioDao playerScenarioDao;
   @Autowired
   private IPlayerScenarioCityDao playerScenarioCityDao;
   @Autowired
   private SoloCityCache soloCityCache;
   @Autowired
   private SoloDramaCache soloDramaCache;
   @Autowired
   private SoloEventCache soloEventCache;
   @Autowired
   private SoloRewardCache soloRewardCache;
   @Autowired
   private IPlayerDao playerDao;
   @Autowired
   private SoloRoadCache soloRoadCache;
   @Autowired
   private IPlayerGeneralMilitaryDao playerGeneralMilitaryDao;
   @Autowired
   private IJuBenDataCache juBenDataCache;
   @Autowired
   private IGeneralService generalService;
   @Autowired
   private GeneralCache generalCache;
   @Autowired
   private TroopCache troopCache;
   @Autowired
   private IJobService jobService;
   @Autowired
   private IBattleService battleService;
   @Autowired
   private ScenarioEventManager scenarioEventManager;
   @Autowired
   private StratagemCache stratagemCache;
   @Autowired
   private IPlayerResourceDao playerResourceDao;
   @Autowired
   private IPlayerService playerService;
   @Autowired
   private IPlayerGeneralCivilDao playerGeneralCivilDao;
   @Autowired
   private IScenarioNpcDao scenarioNpcDao;
   @Autowired
   private IPlayerAttributeDao playerAttributeDao;
   @Autowired
   private ArmiesCache armiesCache;
   @Autowired
   private IPlayerArmyDao playerArmyDao;
   @Autowired
   private IScenarioInfoDao scenarioInfoDao;
   @Autowired
   private ItemsCache itemsCache;
   @Autowired
   private IStoreHouseService storeHouseService;
   @Autowired
   private IStoreHouseDao storeHouseDao;
   @Autowired
   private EquipCache equipCache;
   @Autowired
   private IStoreHouseSellDao storeHouseSellDao;
   @Autowired
   private WdSjpDramaCache wdSjpDramaCache;
   @Autowired
   private BattleDataCache battleDataCache;
   public static Object lock = new Object();

   public void initMiniWinTime() {
      List<ScenarioInfo> list = this.scenarioInfoDao.getModels();
      if (list != null) {
         Iterator var3 = list.iterator();

         while(var3.hasNext()) {
            ScenarioInfo si = (ScenarioInfo)var3.next();
            MiniTimeWinInfo mtwi = new MiniTimeWinInfo();
            mtwi.forceId = si.getForceId();
            mtwi.name = si.getPlayerName();
            mtwi.miniTime = (long)si.getMinTime();
            String str = this.getMiniWinStr(si.getSoloId(), si.getGrade());
            miniWinTime.put(str, mtwi);
         }
      }

   }

   @Transactional
   public byte[] getJuBenList(PlayerDto playerDto, Request request) {
      int playerId = playerDto.playerId;
      PlayerAttribute pa = this.playerAttributeDao.read(playerId);
      char[] cs = pa.getFunctionId().toCharArray();
      if (cs[62] != '1') {
         return JsonBuilder.getJson(State.FAIL, LocalMessages.FUNCTION_NOT_OPEN);
      } else {
         List<PlayerScenario> psList = this.playerScenarioDao.getScenarioByPid(playerId);
         JsonDocument doc = new JsonDocument();
         doc.startObject();
         doc.startArray("jubens");
         SoloDrama soloDrama = null;
         List<Armies> list = this.armiesCache.getJubenOpenList();
         Armies armies = null;
         boolean isOpen = false;
         boolean create = true;

         boolean needOpen;
         while(list.size() > psList.size() && create) {
            create = false;

            for(int i = psList.size(); i >= 0; --i) {
               armies = (Armies)list.get(i);
               needOpen = true;
               Iterator var16 = psList.iterator();

               while(var16.hasNext()) {
                  PlayerScenario ps = (PlayerScenario)var16.next();
                  if (ps.getScenarioId() == ((BattleDrop)armies.getDropMap().get(105)).id) {
                     needOpen = false;
                     break;
                  }
               }

               if (needOpen) {
                  PlayerArmy playerArmy = this.playerArmyDao.getPlayerArmy(playerId, armies.getId());
                  if (playerArmy != null && playerArmy.getWinNum() > 0) {
                     boolean res = this.openNextJuBen(playerId, ((BattleDrop)armies.getDropMap().get(105)).id);
                     if (res) {
                        psList = this.playerScenarioDao.getScenarioByPid(playerId);
                        isOpen = true;
                        create = true;
                        break;
                     }
                  }
               }
            }
         }

         if (!isOpen && list.size() > psList.size()) {
            armies = (Armies)list.get(psList.size());
         } else {
            armies = null;
         }

         PlayerScenario[] pss = new PlayerScenario[psList.size() + 2];
         Iterator var29 = psList.iterator();

         while(var29.hasNext()) {
            PlayerScenario ps2 = (PlayerScenario)var29.next();
            if (this.wdSjpDramaCache.getWorldDramaByDramaId(ps2.getScenarioId()) == null) {
               pss[this.soloDramaCache.getSoloOrder(ps2.getScenarioId()) - 1] = ps2;
            }
         }

         needOpen = true;

         int nextSoloId;
         for(nextSoloId = 0; nextSoloId < pss.length; ++nextSoloId) {
            PlayerScenario ps = pss[nextSoloId];
            if (ps != null) {
               soloDrama = (SoloDrama)this.soloDramaCache.get(ps.getScenarioId());
               if (this.wdSjpDramaCache.getWorldDramaByDramaId(ps.getScenarioId()) == null) {
                  int grade = soloDrama.getGrade();
                  doc.startObject();
                  doc.createElement("sId", ps.getScenarioId());
                  doc.createElement("title", soloDrama.getName());
                  doc.createElement("openLv", soloDrama.getLv());
                  doc.createElement("target", soloDrama.getPlot());
                  doc.startArray("degrees");
                  String[] starLvs = ps.getStarlv().split(",");
                  int curStar = false;
                  Map<Integer, SoloReward> starMap = null;
                  int j = true;
                  int nextStar = 0;
                  SoloReward reward = null;

                  for(int j = 1; j <= grade; ++j) {
                     doc.startObject();
                     doc.createElement("grade", j);
                     starMap = this.soloRewardCache.getBySoloId(ps.getScenarioId(), j);
                     if (j <= starLvs.length) {
                        int curStar = Integer.valueOf(starLvs[j - 1]);
                        doc.createElement("curStar", curStar);
                        doc.createElement("maxStar", 5);
                        String str = this.getMiniWinStr(ps.getScenarioId(), j);
                        MiniTimeWinInfo mtwi = (MiniTimeWinInfo)miniWinTime.get(str);
                        if (mtwi != null) {
                           doc.createElement("winForceId", mtwi.forceId);
                           doc.createElement("winName", mtwi.name);
                           doc.createElement("winTime", mtwi.miniTime * 1000L);
                        }

                        nextStar = curStar + 1 > 5 ? 5 : curStar + 1;
                        doc.createElement("nextStar", nextStar);
                        reward = (SoloReward)starMap.get(nextStar);
                        doc.createElement("food", reward.getReqFood());
                        doc.appendJson(this.getReward(reward));
                        doc.createElement("open", 1);
                        Map<Integer, SoloCity> map = this.soloCityCache.getBySoloId(ps.getScenarioId());
                        doc.appendJson(this.getEventInfo(soloDrama.getEvent(j), map));
                     } else if (j == starLvs.length + 1) {
                        doc.createElement("grade", j);
                        doc.createElement("curStar", 0);
                        doc.createElement("maxStar", 5);
                        doc.createElement("nextStar", 1);
                        reward = (SoloReward)starMap.get(nextStar);
                        doc.createElement("food", reward.getReqFood());
                        doc.appendJson(this.getReward(reward));
                        doc.createElement("open", 0);
                        Map<Integer, SoloCity> map2 = this.soloCityCache.getBySoloId(ps.getScenarioId());
                        doc.appendJson(this.getEventInfo(soloDrama.getEvent(j), map2));
                     }

                     if (starMap != null) {
                        byte[] bytes = this.getGradeTotalReward(starMap);
                        if (bytes != null) {
                           doc.appendJson(bytes);
                        }
                     }

                     doc.endObject();
                  }

                  doc.endArray();
                  doc.endObject();
               }
            }
         }

         int nextSoloId = false;
         if (armies != null) {
            nextSoloId = ((BattleDrop)armies.getDropMap().get(105)).id;
            soloDrama = (SoloDrama)this.soloDramaCache.get(nextSoloId);
            if (soloDrama != null) {
               doc.startObject();
               doc.createElement("sId", soloDrama.getId());
               doc.createElement("title", soloDrama.getName());
               doc.createElement("openLv", soloDrama.getLv());
               doc.createElement("target", soloDrama.getPlot());
               doc.createElement("openPower", soloDrama.getOpenPower());
               doc.startArray("degrees");
               doc.endArray();
               doc.endObject();
            }
         }

         doc.endArray();
         doc.endObject();
         return JsonBuilder.getJson(State.SUCCESS, doc.toByte());
      }
   }

   private byte[] getGradeTotalReward(Map<Integer, SoloReward> starMap) {
      JsonDocument doc = new JsonDocument();

      try {
         Map<Integer, Integer> totalRewards = null;
         Iterator var5 = starMap.keySet().iterator();

         while(true) {
            Map cellMap;
            do {
               Integer key;
               if (!var5.hasNext()) {
                  if (totalRewards == null) {
                     return null;
                  }

                  doc.startArray("totalRewards");

                  for(var5 = totalRewards.keySet().iterator(); var5.hasNext(); doc.endObject()) {
                     key = (Integer)var5.next();
                     doc.startObject();
                     if (key == 43) {
                        int itemId = (Integer)totalRewards.get(key);
                        Items items = (Items)this.itemsCache.get(itemId);
                        doc.createElement("type", items.getPic());
                        doc.createElement("val", 1);
                     } else {
                        doc.createElement("type", key);
                        doc.createElement("val", totalRewards.get(key));
                     }
                  }

                  doc.endArray();
                  return doc.toByte();
               }

               key = (Integer)var5.next();
               SoloReward reward = (SoloReward)starMap.get(key);
               cellMap = reward.getRewardMap();
            } while(cellMap == null);

            Iterator var9 = cellMap.keySet().iterator();

            while(var9.hasNext()) {
               Integer rewardKey = (Integer)var9.next();
               if (totalRewards == null) {
                  totalRewards = new HashMap();
               }

               Integer value = (Integer)totalRewards.get(rewardKey);
               if (value == null) {
                  totalRewards.put(rewardKey, (Integer)cellMap.get(rewardKey));
               } else {
                  totalRewards.put(rewardKey, (Integer)cellMap.get(rewardKey) + value);
               }
            }
         }
      } catch (Exception var11) {
         Exception e = var11;
         errorLog.error(this, e);
         return doc.toByte();
      }
   }

   private byte[] getReward(SoloReward sr) {
      JsonDocument doc = new JsonDocument();
      doc.createElement("bNum", sr.getTeqHyNumber());
      doc.startArray("rewards");
      Iterator var4 = sr.getRewardMap().keySet().iterator();

      while(var4.hasNext()) {
         Integer key = (Integer)var4.next();
         if (key == 43) {
            int itemId = (Integer)sr.getRewardMap().get(key);
            Items items = (Items)this.itemsCache.get(itemId);
            doc.startObject();
            doc.createElement("type", items.getPic());
            doc.createElement("val", 1);
            doc.endObject();
         } else {
            doc.startObject();
            doc.createElement("type", key);
            doc.createElement("val", sr.getRewardMap().get(key));
            doc.endObject();
         }
      }

      doc.endArray();
      return doc.toByte();
   }

   private byte[] getEventInfo(String eventStrs, Map<Integer, SoloCity> map) {
      String[] strs = eventStrs.split(";");
      JsonDocument doc = new JsonDocument();
      doc.startArray("events");
      int event = false;

      for(int i = 0; i < strs.length; ++i) {
         String str = strs[i];
         if (!StringUtils.isBlank(str)) {
            int event = Integer.valueOf(str);
            SoloEvent se = (SoloEvent)this.soloEventCache.get(event);
            if (se != null && StringUtils.isBlank(se.getTrigger()) && !StringUtils.isBlank(se.getFlag1())) {
               String[] flags = se.getFlag1().split(",");
               SoloCity sc = (SoloCity)map.get(Integer.valueOf(flags[1]));
               doc.startObject();
               doc.createElement("cId", flags[1]);
               if (sc != null) {
                  doc.createElement("cCapital", sc.getCapital());
               }

               if (flags.length >= 3) {
                  doc.createElement("cPic", flags[2]);
               }

               doc.createElement("cIntro", se.getIntro());
               doc.endObject();
            }
         }
      }

      doc.endArray();
      return doc.toByte();
   }

   @Transactional
   public void openJuBenNextStar(int playerId, int soloId, int grade) {
   }

   @Transactional
   public boolean openNextJuBen(int playerId, int soloId) {
      try {
         Player player = this.playerDao.read(playerId);
         PlayerScenario playerScenario = this.playerScenarioDao.getScenarioByPidSid(playerId, soloId);
         Date date = new Date();
         if (playerScenario != null) {
            return false;
         } else {
            playerScenario = new PlayerScenario();
            playerScenario.setPlayerId(playerId);
            playerScenario.setScenarioId(soloId);
            playerScenario.setAttackable(1);
            playerScenario.setStarttime(date);
            playerScenario.setEndtime(date);
            playerScenario.setGrade(1);
            playerScenario.setRewarded(0);
            playerScenario.setState(0);
            playerScenario.setEventInfo("");
            playerScenario.setStarlv("0,");
            playerScenario.setCurstar(5);
            playerScenario.setJieBingCount(0);
            playerScenario.setOvertime(0L);
            this.playerScenarioDao.create(playerScenario);
            Map<Integer, SoloCity> map = this.soloCityCache.getBySoloId(soloId);
            if (map == null) {
               return false;
            } else {
               int belong = false;
               Iterator var9 = map.values().iterator();

               while(var9.hasNext()) {
                  SoloCity sc = (SoloCity)var9.next();
                  PlayerScenarioCity playerScenarioCity = new PlayerScenarioCity();
                  playerScenarioCity.setCityId(sc.getId());
                  int belong = 0;
                  if (sc.getBelong() == 0) {
                     belong = player.getForceId();
                  }

                  playerScenarioCity.setForceId(belong);
                  playerScenarioCity.setPlayerId(playerId);
                  playerScenarioCity.setScenarioId(sc.getSoloId());
                  playerScenarioCity.setState(0);
                  playerScenarioCity.setTrickinfo("");
                  playerScenarioCity.setUpdatetime(date.getTime());
                  playerScenarioCity.setTitle(0);
                  playerScenarioCity.setBorder(0);
                  playerScenarioCity.setEventInfo("");
                  this.playerScenarioCityDao.create(playerScenarioCity);
               }

               return true;
            }
         }
      } catch (Exception var11) {
         Exception e = var11;
         errorLog.error(this, e);
         return false;
      }
   }

   public void initJuBenNpcs(PlayerDto playerDto, int scenarioId, int grade) {
      try {
         List<ScenarioNpc> snList = new LinkedList();
         int npcType = true;
         int state = false;
         Date date = new Date();
         Map<Integer, SoloCity> scMap = this.dataGetter.getSoloCityCache().getBySoloId(scenarioId);
         Iterator var10 = scMap.values().iterator();

         while(true) {
            SoloCity sc;
            List npcList;
            do {
               do {
                  if (!var10.hasNext()) {
                     this.dataGetter.getScenarioNpcDao().batchCreate(snList);
                     return;
                  }

                  sc = (SoloCity)var10.next();
                  npcList = (List)sc.getNpcListMap().get(grade);
               } while(npcList == null);
            } while(npcList.size() == 0);

            int forceId = 0;
            if (sc.getBelong() == 0) {
               forceId = playerDto.forceId;
            }

            if (sc.getBelong() > 100) {
               forceId = sc.getBelong();
            }

            int locationId = sc.getId();
            Iterator var15 = npcList.iterator();

            while(var15.hasNext()) {
               Integer armyId = (Integer)var15.next();
               ScenarioNpc scenarioNpc = new ScenarioNpc();
               scenarioNpc.setVId(scenarioNpcVId.incrementAndGet());
               scenarioNpc.setPlayerId(playerDto.playerId);
               scenarioNpc.setScenarioId(scenarioId);
               scenarioNpc.setLocationId(locationId);
               scenarioNpc.setForceId(forceId);
               scenarioNpc.setNpcType(2);
               scenarioNpc.setArmyId(armyId);
               Army army = (Army)this.dataGetter.getArmyCache().get(armyId);
               scenarioNpc.setHp(army.getArmyHp());
               scenarioNpc.setTacticVal(1);
               scenarioNpc.setState(0);
               scenarioNpc.setAddTime(date);
               snList.add(scenarioNpc);
            }
         }
      } catch (Exception var18) {
         Exception e = var18;
         ErrorSceneLog.getInstance().error("JuBenService.InitJuBenNpcs catch Exception", e);
      }
   }

   private void updateJuBen(int playerId, int soloId, int grade) {
      Date starttime = new Date();
      Map<Integer, SoloReward> srMap = this.soloRewardCache.getBySoloId(soloId, grade);
      long endTime = (long)((SoloReward)srMap.get(5)).getReqTime();
      endTime = starttime.getTime() + endTime * 1000L;
      this.playerScenarioDao.updateInit(playerId, soloId, grade, starttime, new Date(endTime), 5, 0);
      Player player = this.playerDao.read(playerId);
      Map<Integer, SoloCity> map = this.soloCityCache.getBySoloId(soloId);
      int belong = false;

      SoloCity sc;
      int belong;
      for(Iterator var12 = map.values().iterator(); var12.hasNext(); this.playerScenarioCityDao.updateInit(playerId, sc.getSoloId(), sc.getId(), 0, belong, "", starttime.getTime(), 0, 0, "")) {
         sc = (SoloCity)var12.next();
         PlayerScenarioCity playerScenarioCity = new PlayerScenarioCity();
         playerScenarioCity.setCityId(sc.getId());
         belong = 0;
         if (sc.getBelong() == 0) {
            belong = player.getForceId();
         } else if (sc.getBelong() > 100) {
            belong = sc.getBelong();
         }
      }

   }

   public void initAllJuBenIngToCache() {
      List<PlayerScenario> list = this.playerScenarioDao.getListByState();
      if (list != null) {
         Date date = new Date();
         Iterator var4 = list.iterator();

         while(var4.hasNext()) {
            PlayerScenario ps = (PlayerScenario)var4.next();

            try {
               long endTime = 0L;
               ServerTime st = GcldInitManager.lastServerTime;
               if (st != null) {
                  endTime = date.getTime() - st.getEndTime().getTime() + ps.getEndtime().getTime() + 10000L;
               }

               if (endTime < ps.getEndtime().getTime()) {
                  Map<Integer, SoloReward> srMap = this.soloRewardCache.getBySoloId(ps.getScenarioId(), ps.getGrade());
                  endTime = (long)((SoloReward)srMap.get(ps.getCurstar())).getReqTime();
                  endTime = date.getTime() + endTime * 1000L;
               }

               Date eTime = new Date(endTime);
               ps.setEndtime(eTime);
               this.playerScenarioDao.updateEndTime(ps.getPlayerId(), ps.getScenarioId(), eTime);
               this.cacheJuBen(ps.getPlayerId(), ps);
               this.recoverJuBenBattles(ps);
            } catch (Exception var9) {
               Exception e = var9;
               errorLog.error("JuBenService initAllJuBenIngToCache playerId：" + ps.getPlayerId() + " soId：" + ps.getScenarioId() + e.getMessage());
            }
         }
      }

   }

   private void recoverJuBenBattles(PlayerScenario playerScenario) {
      try {
         int playerId = playerScenario.getPlayerId();
         int scenarioId = playerScenario.getScenarioId();
         Player player = this.dataGetter.getPlayerDao().read(playerId);
         int playerForceId = player.getForceId();
         List<PlayerGeneralMilitary> pgmList = this.dataGetter.getPlayerGeneralMilitaryDao().getMilitaryList(playerId);
         Map<Integer, List<PlayerGeneralMilitary>> pgmCityIdMap = new HashMap();

         PlayerGeneralMilitary pgm;
         Object list;
         for(Iterator var9 = pgmList.iterator(); var9.hasNext(); ((List)list).add(pgm)) {
            pgm = (PlayerGeneralMilitary)var9.next();
            list = (List)pgmCityIdMap.get(pgm.getJubenLoId());
            if (list == null) {
               list = new LinkedList();
               pgmCityIdMap.put(pgm.getJubenLoId(), list);
            }
         }

         List<PlayerScenarioCity> psList = this.playerScenarioCityDao.getSCityByPidSid(playerId, scenarioId);
         Iterator var24 = psList.iterator();

         while(var24.hasNext()) {
            PlayerScenarioCity playerScenarioCity = (PlayerScenarioCity)var24.next();
            int cityId = playerScenarioCity.getCityId();
            int cityForceId = playerScenarioCity.getForceId();
            List<ScenarioNpc> scList = this.dataGetter.getScenarioNpcDao().getByPlayerIdLocationId(playerId, cityId);
            List<ScenarioNpc> scAttList = new LinkedList();
            List<ScenarioNpc> scDefList = new LinkedList();
            Iterator var17 = scList.iterator();

            while(var17.hasNext()) {
               ScenarioNpc scenarioNpc = (ScenarioNpc)var17.next();
               if (scenarioNpc.getForceId() == cityForceId) {
                  scDefList.add(scenarioNpc);
               } else {
                  scAttList.add(scenarioNpc);
               }
            }

            boolean hasAttArmy = false;
            boolean hasDefArmy = false;
            List<PlayerGeneralMilitary> pgmListInThisCity = (List)pgmCityIdMap.get(cityId);
            boolean hasPgmInThisCity = pgmListInThisCity != null && pgmListInThisCity.size() > 0;
            if (playerForceId == cityForceId) {
               hasAttArmy = scAttList.size() > 0;
               hasDefArmy = hasPgmInThisCity || scDefList.size() > 0;
            } else {
               hasAttArmy = scAttList.size() > 0 || hasPgmInThisCity;
               hasDefArmy = scDefList.size() > 0;
            }

            if (hasAttArmy && hasDefArmy) {
               this.fireRecoverJubenBattle(player, cityId);
            }
         }
      } catch (Exception var20) {
         Exception e = var20;
         ErrorSceneLog.getInstance().error("JuBenService recoverJuBenBattles catch Exception. playerId：" + playerScenario.getPlayerId() + " soId：" + playerScenario.getScenarioId(), e);
      }

   }

   private void fireRecoverJubenBattle(Player player, int cityId) {
      try {
         int playerId = player.getPlayerId();
         Builder builder = BuilderFactory.getInstance().getBuilder(18);
         String battleId = NewBattleManager.getBattleId(18, playerId, cityId);
         Battle juBenCityBattle = NewBattleManager.getInstance().createBattle(battleId);
         if (juBenCityBattle == null) {
            ErrorSceneLog.getInstance().appendErrorMsg("create battle fail").appendBattleId(battleId).append("playerId", playerId).append("cityId", cityId).appendClassName("JuBenService").appendMethodName("fireARecoverJubenBattle").flush();
            return;
         }

         Terrain terrain = builder.getTerrain(-1, cityId, this.dataGetter);
         BattleAttacker battleAttacker = new BattleAttacker();
         battleAttacker.attType = 7;
         battleAttacker.attForceId = 0;
         battleAttacker.attPlayerId = playerId;
         battleAttacker.attPlayer = player;
         juBenCityBattle.init(battleAttacker, 18, cityId, this.dataGetter, false, terrain.getValue());
         builder.dealUniqueStaff(this.dataGetter, juBenCityBattle, -1, cityId);
      } catch (Exception var9) {
         Exception e = var9;
         ErrorSceneLog.getInstance().error("JuBenService fireRecoverJubenBattle catch Exception.", e);
      }

   }

   private JuBenDto cacheJuBen(int playerId, int sId) {
      PlayerScenario ps = this.playerScenarioDao.getScenarioByPidSid(playerId, sId);
      return this.cacheJuBen(playerId, ps);
   }

   private JuBenDto cacheJuBen(int playerId, PlayerScenario ps) {
      JuBenDto juBenDto = new JuBenDto();
      juBenDto.player_id = ps.getPlayerId();
      juBenDto.juBen_id = ps.getScenarioId();
      juBenDto.startTime = ps.getStarttime().getTime();
      juBenDto.endTime = ps.getEndtime().getTime();
      juBenDto.overTime = ps.getOvertime();
      juBenDto.grade = ps.getGrade();
      SoloDrama soloDrama = (SoloDrama)this.soloDramaCache.get(ps.getScenarioId());
      juBenDto.title = soloDrama.getName();
      juBenDto.star = ps.getCurstar();
      juBenDto.state = ps.getState();
      juBenDto.target = soloDrama.getPlot();
      juBenDto.jieBingCount = ps.getJieBingCount();
      Player player = this.playerDao.read(ps.getPlayerId());
      juBenDto.player_force_id = player.getForceId();
      juBenDto.maxJieBingCount = this.dataGetter.getSoloRewardCache().getMaxJieBingCount(juBenDto.juBen_id, juBenDto.grade, juBenDto.star);
      juBenDto.roadLinked = new CopyOnWriteArraySet();
      juBenDto.royalJadeBelong = -1;
      juBenDto.royalEndTime = 0L;
      juBenDto.cityChangeMap = new ConcurrentHashMap();
      if (soloDrama.getId() == 11) {
         juBenDto.mengdeLocation = 142;
      }

      juBenDto.isMengdeSafe = false;
      if (juBenDto.juBen_id == 9) {
         juBenDto.roadLinked.add(123);
         if (juBenDto.grade >= 1 && juBenDto.grade <= 3) {
            juBenDto.roadLinked.add(121);
         }
      }

      Map<Integer, SoloCity> map = this.soloCityCache.getBySoloId(ps.getScenarioId());
      Iterator list = map.values().iterator();

      while(list.hasNext()) {
         SoloCity sc = (SoloCity)list.next();
         if (sc.getCapital() == 1) {
            if (sc.getBelong() == 0) {
               juBenDto.capital = sc.getId();
            } else {
               juBenDto.npcCapital = sc.getId();
            }
         }
      }

      int grade = juBenDto.grade;
      list = null;

      String soloCity;
      try {
         String eventIds = grade == 1 ? soloDrama.getEvent1() : (grade == 2 ? soloDrama.getEvent2() : (grade == 3 ? soloDrama.getEvent3() : (grade == 4 ? soloDrama.getEvent4() : soloDrama.getEvent5())));
         soloCity = ps.getEventInfo();
         List<ScenarioEvent> list = this.scenarioEventManager.addScenarioToPlayer(playerId, eventIds, soloCity);
         juBenDto.eventList = list;
      } catch (Exception var15) {
         Exception e = var15;
         errorLog.error("addScenarioToPlayer fail...playerId:" + playerId + "\tid:" + juBenDto.juBen_id);
         errorLog.error(e.getMessage());
         errorLog.error(this, e);
      }

      List<PlayerScenarioCity> psList = this.playerScenarioCityDao.getSCityByPidSid(playerId, ps.getScenarioId());
      juBenDto.juBenCityDtoMap = new HashMap();
      soloCity = null;
      Iterator var12 = psList.iterator();

      while(var12.hasNext()) {
         PlayerScenarioCity psc = (PlayerScenarioCity)var12.next();
         JuBenCityDto jcd = new JuBenCityDto();
         jcd.cityId = psc.getCityId();
         SoloCity soloCity = (SoloCity)this.soloCityCache.get(psc.getCityId());
         jcd.cityName = soloCity.getName();
         jcd.forceId = psc.getForceId();
         jcd.vId = psc.getVId();
         jcd.state = 0;
         jcd.title = 0;
         if (jcd.trickDto == null) {
            jcd.trickDto = new HashMap();
         }

         this.restoreTrickInfo(jcd.trickDto, psc.getTrickinfo());
         jcd.terrain = soloCity.getTerrain();
         jcd.terrianType = soloCity.getTerrainEffectType();
         jcd.update = false;
         juBenDto.juBenCityDtoMap.put(psc.getCityId(), jcd);
         StringBuilder sb = new StringBuilder();
         sb.append(18).append("_").append(playerId).append("_").append(psc.getCityId());
         jcd.battleId = sb.toString();
         if (jcd.cityId == 121 && jcd.forceId == juBenDto.player_force_id) {
            juBenDto.royalJadeBelong = 0;
         }
      }

      var12 = juBenDto.juBenCityDtoMap.values().iterator();

      while(var12.hasNext()) {
         JuBenCityDto ci = (JuBenCityDto)var12.next();
         if (juBenDto.capital != ci.cityId && juBenDto.npcCapital != ci.cityId) {
            ci.title = this.getSurroundState(juBenDto, ci);
         }
      }

      JuBenManager.getInstance().putJuBen(juBenDto);
      this.jobService.addJob("juBenService", "juBenDeal", String.valueOf(playerId), juBenDto.endTime, false);
      return juBenDto;
   }

   private void restoreTrickInfo(HashMap<Integer, HashMap<String, TrickDto>> trickDto, String trickinfo) {
      if (trickDto == null) {
         trickDto = new HashMap();
      }

      if (!StringUtils.isBlank(trickinfo)) {
         HashMap<String, TrickDto> map = null;
         String[] single = trickinfo.split("#");

         for(int i = 0; i < single.length; ++i) {
            String value = single[i];
            if (!StringUtils.isBlank(value)) {
               String[] cell = value.split("-");
               if (cell.length >= 5) {
                  int id = Integer.parseInt(cell[0]);
                  Stratagem stratagem = (Stratagem)this.dataGetter.getStratagemCache().get(id);
                  if (stratagem != null) {
                     TrickDto dto = new TrickDto(cell, this.dataGetter);
                     map = (HashMap)trickDto.get(dto.getForceId());
                     if (map == null) {
                        map = new HashMap();
                        map.put(dto.getType(), dto);
                        trickDto.put(dto.getForceId(), map);
                     } else {
                        map.put(dto.getType(), dto);
                     }
                  }
               }
            }
         }

      }
   }

   public byte[] getJuBenReward(PlayerDto playerDto) {
      int playerId = playerDto.playerId;
      JuBenDto juBenDto = JuBenManager.getInstance().getByPid(playerId);
      if (juBenDto != null && juBenDto.state != 1) {
         JsonDocument doc2 = new JsonDocument();
         doc2.startObject();

         try {
            if (!juBenDto.isWin) {
               doc2.createElement("target", juBenDto.target);
               doc2.createElement("win", false);
            } else {
               doc2.createElement("target", juBenDto.target);
               doc2.createElement("win", juBenDto.isWin);
               doc2.createElement("curStar", juBenDto.star);
               doc2.createElement("maxStar", 5);
               Map<Integer, SoloReward> map = this.soloRewardCache.getBySoloId(juBenDto.juBen_id, juBenDto.grade);
               PlayerScenario playerScenario = this.playerScenarioDao.getScenarioByPidSid(playerId, juBenDto.juBen_id);
               int rewarded = playerScenario.getRewarded();
               List<SoloReward> list = new ArrayList();
               int pow = false;
               int start = (juBenDto.grade - 1) * 5;
               int i = start;

               label160:
               while(true) {
                  if (i >= start + juBenDto.star) {
                     String[] openLv = playerScenario.getStarlv().split(",");
                     StringBuilder sb = new StringBuilder();
                     int orgLv = false;

                     for(int j = 0; j < openLv.length; ++j) {
                        int orgLv = Integer.valueOf(openLv[j]);
                        if (j + 1 == juBenDto.grade && orgLv < juBenDto.star) {
                           orgLv = juBenDto.star;
                        }

                        sb.append(orgLv).append(",");
                     }

                     if (juBenDto.star >= 4) {
                        SoloDrama soloDrama = (SoloDrama)this.soloDramaCache.get(juBenDto.juBen_id);
                        if (juBenDto.grade >= openLv.length && juBenDto.grade < soloDrama.getGrade()) {
                           sb.append(0).append(",");
                        }
                     }

                     long consumeTime = 0L;

                     for(int k = 5; k > juBenDto.star; --k) {
                        SoloReward sr = (SoloReward)map.get(k);
                        consumeTime += (long)sr.getReqTime();
                     }

                     SoloReward srd = (SoloReward)map.get(juBenDto.star);
                     long curStrPassTime = (long)srd.getReqTime() - (juBenDto.endTime - juBenDto.overTime) / 1000L;
                     if (curStrPassTime < 0L) {
                        curStrPassTime = 0L;
                     }

                     consumeTime += curStrPassTime;
                     doc2.createElement("consumeTime", consumeTime);
                     doc2.startArray("rewards");
                     Map<Integer, Integer> totalRewardMap = new HashMap();
                     List<Items> itemsList = new ArrayList();
                     Iterator var22 = list.iterator();

                     label139:
                     while(var22.hasNext()) {
                        SoloReward sr2 = (SoloReward)var22.next();
                        doc2.startObject();
                        doc2.createElement("star", sr2.getStar());
                        doc2.startArray("res");
                        Iterator var24 = sr2.getRewardMap().keySet().iterator();

                        while(true) {
                           Items items;
                           label134:
                           while(true) {
                              while(var24.hasNext()) {
                                 Integer key = (Integer)var24.next();
                                 if (key == 43) {
                                    int itemId = (Integer)sr2.getRewardMap().get(key);
                                    items = (Items)this.itemsCache.get(itemId);
                                    if (items.getChangeItemId() <= 0) {
                                       break label134;
                                    }

                                    Items changeItem = (Items)this.itemsCache.get(items.getChangeItemId());
                                    if (changeItem == null) {
                                       break label134;
                                    }

                                    int changeItemId = changeItem.getId();
                                    int changeItemType = changeItem.getType();
                                    EquipCoordinates ecd = this.equipCache.getEquipCoordinateByItemId(changeItem.getId());
                                    if (ecd != null) {
                                       List<StoreHouse> shList = this.storeHouseDao.getByItemId(playerDto.playerId, changeItemId, 10);
                                       if (shList != null && shList.size() > 0) {
                                          continue;
                                       }
                                    }

                                    EquipProset equipProset = this.equipCache.getEquipProsetByItemId(changeItemId);
                                    if (equipProset != null) {
                                       List<StoreHouse> shList2 = this.storeHouseDao.getByItemId(playerId, changeItemId, 14);
                                       if (shList2 != null && shList2.size() > 0) {
                                          continue;
                                       }
                                    }

                                    EquipProset canCompoundProset = this.equipCache.getProsetBySubSuitId(changeItemId);
                                    List shList3;
                                    if (canCompoundProset != null) {
                                       shList3 = this.storeHouseDao.getByItemId(playerId, canCompoundProset.getItemId(), 14);
                                       if (shList3 != null && shList3.size() > 0) {
                                          continue;
                                       }
                                    }

                                    shList3 = this.storeHouseDao.getByItemId(playerDto.playerId, changeItemId, StoreHouseService.getStoreHouseType(changeItemType));
                                    if (shList3 == null || shList3.size() <= 0) {
                                       StoreHouseSell shs = this.storeHouseSellDao.getByItemId(playerDto.playerId, changeItemId, StoreHouseService.getStoreHouseType(changeItemType));
                                       if (shs == null) {
                                          break label134;
                                       }
                                    }
                                 } else if (key == 7) {
                                    this.storeHouseService.gainGem(this.playerDao.read(playerId), (Integer)sr2.getRewardMap().get(key), 1, "剧本奖励宝石", (String)null);
                                    doc2.startObject();
                                    doc2.createElement("type", key);
                                    doc2.createElement("val", sr2.getRewardMap().get(key));
                                    doc2.endObject();
                                 } else {
                                    doc2.startObject();
                                    doc2.createElement("type", key);
                                    doc2.createElement("val", sr2.getRewardMap().get(key));
                                    doc2.endObject();
                                    if (totalRewardMap.containsKey(key)) {
                                       totalRewardMap.put(key, (Integer)totalRewardMap.get(key) + (Integer)sr2.getRewardMap().get(key));
                                    } else {
                                       totalRewardMap.put(key, (Integer)sr2.getRewardMap().get(key));
                                    }
                                 }
                              }

                              doc2.endArray();
                              doc2.endObject();
                              continue label139;
                           }

                           itemsList.add(items);
                           doc2.startObject();
                           doc2.createElement("type", items.getPic());
                           doc2.createElement("val", 1);
                           doc2.endObject();
                        }
                     }

                     doc2.endArray();
                     this.playerScenarioDao.updateRewardStarLv(playerId, playerScenario.getScenarioId(), sb.toString(), rewarded);
                     List<ResourceDto> rewardList = new ArrayList();
                     Iterator var49 = totalRewardMap.keySet().iterator();

                     while(var49.hasNext()) {
                        Integer key2 = (Integer)var49.next();
                        ResourceDto rd = new ResourceDto(key2, (double)(Integer)totalRewardMap.get(key2));
                        rewardList.add(rd);
                     }

                     if (totalRewardMap.containsKey(5)) {
                        this.playerService.updateExpAndPlayerLevel(playerId, (long)(Integer)totalRewardMap.get(5), "剧本胜利增加经验", new int[0]);
                     }

                     this.playerResourceDao.addResourceIgnoreMax(playerId, rewardList, "剧本结束奖励", true);
                     var49 = itemsList.iterator();

                     while(true) {
                        if (!var49.hasNext()) {
                           break label160;
                        }

                        Items items2 = (Items)var49.next();
                        this.storeHouseService.gainItems(playerId, 1, items2.getId(), LocalMessages.T_LOG_ITEM_9, true);
                     }
                  }

                  int pow = (int)Math.pow(2.0, (double)i);
                  if ((rewarded & pow) != pow || this.isWorldDrama(juBenDto.juBen_id)) {
                     list.add((SoloReward)map.get(i + 1 - start));
                     rewarded += pow;
                  }

                  ++i;
               }
            }

            doc2.createElement("reward", true);
            int phantomExp = this.caculatePhantomCopperExp(playerId, juBenDto);
            this.dealWithWorldDrama(juBenDto, playerDto);
            this.clearJubBenOver(juBenDto, playerId);
            doc2.createElement("phantomExp", phantomExp);
            doc2.endObject();
            this.scenarioNpcDao.deleteAll(playerId);
         } catch (Exception var35) {
            Exception e = var35;
            errorLog.error("JuBenService getJuBenReward playerId " + playerId, e);
         }

         JuBenManager.getInstance().clearByVid(playerId);
         JsonDocument doc3 = new JsonDocument();
         doc3.startObject();
         doc3.createElement("inJuBen", false);
         doc3.endObject();
         Players.push(playerId, PushCommand.PUSH_UPDATE, doc3.toByte());
         return JsonBuilder.getJson(State.SUCCESS, doc2.toByte());
      } else {
         return JsonBuilder.getJson(State.FAIL, LocalMessages.T_COMM_10012);
      }
   }

   private void dealWithWorldDrama(JuBenDto juBenDto, PlayerDto playerDto) {
      try {
         WdSjpDrama drama = this.dataGetter.getWdSjpDramaCache().getWorldDramaByDramaIdAndGrade(juBenDto.juBen_id, juBenDto.grade);
         if (drama != null) {
            WdSjp wdSjp = (WdSjp)this.dataGetter.getWdSjpCache().get(5);
            if (wdSjp != null) {
               PlayerBattleAttribute pba = this.dataGetter.getPlayerBattleAttributeDao().read(playerDto.playerId);
               int todayCount = pba == null ? 0 : pba.getEventWorldDramaCountToday();
               if (juBenDto.isWin) {
                  this.dataGetter.getPlayerBattleAttributeDao().addEventWorldDramaCountToday(playerDto.playerId);
                  WorldDramaTimesCache cache = WorldDramaTimesCache.getInstatnce();
                  int allTimes = cache.getTimesByPIDAndSIdAndGrade(playerDto.playerId, juBenDto.juBen_id, juBenDto.grade);
                  int updateResult = cache.updateTimes(playerDto.playerId, drama.getDramaId(), drama.getDifficulty(), allTimes + 1);
                  if (updateResult <= 0) {
                     errorLog.error("cache updateTimes return 0..playerId:" + playerDto.playerId + " dramaId:" + drama.getDramaId() + " grade:" + drama.getDifficulty() + " times:" + allTimes + 1);
                  }

                  todayCount += updateResult > 0 ? 1 : 0;
                  int openTech = drama.getOpenTech();
                  List<WdSjpDrama> soloIdList = this.dataGetter.getWdSjpDramaCache().getDramaListByOpenTech(openTech);
                  if (soloIdList == null || soloIdList.isEmpty()) {
                     errorLog.error("dealWithWorldDrama ..OpenTechDramasList is empty. openTech:" + openTech);
                     return;
                  }

                  boolean isThisTechDramaOver = true;
                  Iterator var14 = soloIdList.iterator();

                  while(var14.hasNext()) {
                     WdSjpDrama singleDrama = (WdSjpDrama)var14.next();
                     int useTimes = cache.getTimesByPIDAndSIdAndGrade(playerDto.playerId, singleDrama.getDramaId(), singleDrama.getDifficulty());
                     int maxTimes = singleDrama.getNumMax();
                     if (useTimes < maxTimes) {
                        isThisTechDramaOver = false;
                        break;
                     }
                  }

                  int techIndex = this.dataGetter.getWdSjpDramaCache().getTechIndexByTechId(openTech);
                  if (isThisTechDramaOver) {
                     Players.push(playerDto.playerId, PushCommand.PUSH_WORLD_DRAMA, JsonBuilder.getSimpleJson("worldDramaGrade", techIndex));
                  }

                  errorLog.error(LogUtil.formatWorldDramaLog(playerDto, juBenDto, juBenDto.star));
               }

               if (todayCount >= wdSjp.getNumMax()) {
                  String msg = LocalMessages.JUBEN_TODAY_COUNT_IS_ZERO;
                  this.dataGetter.getChatService().sendSystemChat("SYS2ONE", playerDto.playerId, playerDto.forceId, msg, (ChatLink)null);
               } else {
                  this.dataGetter.getCityService().addPlayerNextEvent(playerDto.playerId, playerDto.forceId, 5, false);
               }
            } else {
               errorLog.error("dealWithWorldDrama wdsjp is null...");
            }
         }
      } catch (Exception var17) {
         Exception e = var17;
         errorLog.error(this, e);
      }

   }

   private String getMiniWinStr(int soId, int grade) {
      StringBuilder sb = new StringBuilder();
      sb.append(soId).append("_").append(grade);
      return sb.toString();
   }

   @Transactional
   public void juBenOver(int playerId, JuBenDto juBenDto, boolean win) {
      juBenDto.state = 0;
      juBenDto.isWin = win;
      juBenDto.overTime = System.currentTimeMillis();
      this.sendOverDialog(juBenDto, playerId, win);
      if (win && juBenDto.star == 5) {
         Map<Integer, SoloReward> map = this.soloRewardCache.getBySoloId(juBenDto.juBen_id, juBenDto.grade);
         long consumeTime = 0L;

         for(int i = 5; i > juBenDto.star; --i) {
            SoloReward sr = (SoloReward)map.get(i);
            consumeTime += (long)sr.getReqTime();
         }

         SoloReward srd = (SoloReward)map.get(juBenDto.star);
         long curStrPassTime = (long)srd.getReqTime() - (juBenDto.endTime - juBenDto.overTime) / 1000L;
         if (curStrPassTime < 0L) {
            curStrPassTime = 0L;
         }

         consumeTime += curStrPassTime;
         String str = this.getMiniWinStr(juBenDto.juBen_id, juBenDto.grade);
         if (miniWinTime.get(str) == null || ((MiniTimeWinInfo)miniWinTime.get(str)).miniTime > consumeTime) {
            MiniTimeWinInfo mtwi = new MiniTimeWinInfo();
            Player player = this.playerDao.read(playerId);
            mtwi.forceId = player.getForceId();
            mtwi.name = player.getPlayerName();
            mtwi.miniTime = consumeTime;
            if (miniWinTime.get(str) == null) {
               miniWinTime.put(str, mtwi);
               ScenarioInfo scenarioInfo = new ScenarioInfo();
               scenarioInfo.setGrade(juBenDto.grade);
               scenarioInfo.setSoloId(juBenDto.juBen_id);
               scenarioInfo.setMinTime((int)consumeTime);
               scenarioInfo.setPlayerId(playerId);
               scenarioInfo.setForceId(player.getForceId());
               scenarioInfo.setPlayerName(player.getPlayerName());
               this.scenarioInfoDao.create(scenarioInfo);
            } else {
               miniWinTime.put(str, mtwi);
               this.scenarioInfoDao.updateMinTime(juBenDto.juBen_id, juBenDto.grade, (int)consumeTime, playerId, player.getForceId(), player.getPlayerName());
            }

            if (this.dataGetter.getWdSjpDramaCache().getWorldDramaByDramaId(juBenDto.juBen_id) == null) {
               String msg = MessageFormatter.format(LocalMessages.JUBEN_WIN_MIN_TIME, new Object[]{ColorUtil.getSpecialColorMsg(player.getPlayerName()), juBenDto.title, this.getGradeStr(juBenDto.grade)});
               this.dataGetter.getChatService().sendSystemChat("GLOBAL", 0, 0, msg, (ChatLink)null);
            }
         }
      }

      this.playerScenarioDao.updateStateOverTime(playerId, juBenDto.juBen_id, 0, System.currentTimeMillis());
      JsonDocument doc1 = new JsonDocument();
      doc1.startObject();
      doc1.createElement("juBenOver", true);
      doc1.endObject();
      Players.push(playerId, PushCommand.PUSH_UPDATE, doc1.toByte());
   }

   private void sendOverDialog(JuBenDto juBenDto, int playerId, boolean win) {
      if (juBenDto.juBen_id == 10001) {
         if (win) {
            ScenarioEventJsonBuilder.sendDialog(playerId, 10001003, (Object)null);
         }
      } else if (juBenDto.juBen_id == 10002) {
         ScenarioEventJsonBuilder.sendDialog(playerId, 10002002, (Object)null);
      } else if (juBenDto.juBen_id == 10003) {
         ScenarioEventJsonBuilder.sendDialog(playerId, 10003001, (Object)null);
      } else if (juBenDto.juBen_id == 10004) {
         ScenarioEventJsonBuilder.sendDialog(playerId, 10004001, (Object)null);
      } else if (juBenDto.juBen_id == 10009) {
         ScenarioEventJsonBuilder.sendDialog(playerId, 10009001, (Object)null);
      } else if (juBenDto.juBen_id == 11 && win) {
         ScenarioEventJsonBuilder.sendDialog(playerId, 11003, (Object)null);
      }

   }

   private String getGradeStr(int grade) {
      if (grade == 1) {
         return LocalMessages.JUBEN_GRADE_1;
      } else if (grade == 2) {
         return LocalMessages.JUBEN_GRADE_2;
      } else if (grade == 3) {
         return LocalMessages.JUBEN_GRADE_3;
      } else if (grade == 4) {
         return LocalMessages.JUBEN_GRADE_4;
      } else {
         return grade == 5 ? LocalMessages.JUBEN_GRADE_5 : LocalMessages.JUBEN_GRADE_1;
      }
   }

   private void clearOneSideOfBattle(Player player, JuBenCityDto juBenCityDto, Battle battle, boolean playerSide) {
      boolean clearAttSide = false;
      if (playerSide && battle.getAttBaseInfo().getForceId() == player.getForceId() || !playerSide && battle.getAttBaseInfo().getForceId() != player.getForceId()) {
         clearAttSide = true;
      } else if ((!playerSide || battle.getDefBaseInfo().getForceId() != player.getForceId()) && (playerSide || battle.getDefBaseInfo().getForceId() == player.getForceId())) {
         ErrorSceneLog.getInstance().appendErrorMsg("battle forceId error. AttSide will be cleared").appendBattleId(battle.getBattleId()).appendPlayerId(player.getPlayerId()).appendPlayerName(player.getPlayerName()).append("player forceId", player.getForceId()).append("playerSide", playerSide).append("Att ForceId", battle.getAttBaseInfo().getForceId()).append("Def ForceId", battle.getDefBaseInfo().getForceId()).appendClassName("JuBenService").appendMethodName("clearOneSideOfBattle").flush();
         clearAttSide = true;
      } else {
         clearAttSide = false;
      }

      boolean delSucc;
      CampArmy temp;
      Iterator var8;
      if (clearAttSide) {
         synchronized(battle.getBattleId()) {
            var8 = battle.getAttCamp().iterator();

            while(var8.hasNext()) {
               temp = (CampArmy)var8.next();
               if (temp.getPlayerId() > 0 && !temp.isPhantom()) {
                  NewBattleManager.getInstance().quitBattle(battle, temp.getPlayerId(), new int[]{temp.getGeneralId()});
               }

               temp.setArmyHpLoss(temp.getArmyHp());
               temp.setArmyHp(0);
            }

            battle.getAttBaseInfo().setNum(0);
            battle.getAttList().clear();
         }

         delSucc = BattleScheduler.getInstance().removeBattle(battle);
         if (delSucc) {
            battle.doBattle(this.dataGetter, battle.getStartTime());
         } else {
            ErrorSceneLog.getInstance().appendErrorMsg("removeBattle battle fail").appendBattleId(battle.getBattleId()).appendPlayerId(player.getPlayerId()).appendPlayerName(player.getPlayerName()).appendClassName("JuBenService").appendMethodName("clearOneSideOfBattle").flush();
         }
      } else {
         synchronized(battle.getBattleId()) {
            var8 = battle.getDefCamp().iterator();

            while(var8.hasNext()) {
               temp = (CampArmy)var8.next();
               if (temp.getPlayerId() > 0 && !temp.isPhantom()) {
                  NewBattleManager.getInstance().quitBattle(battle, temp.getPlayerId(), new int[]{temp.getGeneralId()});
               }

               temp.setArmyHpLoss(temp.getArmyHp());
               temp.setArmyHp(0);
            }

            battle.getDefBaseInfo().setNum(0);
            battle.getDefList().clear();
         }

         delSucc = BattleScheduler.getInstance().removeBattle(battle);
         if (delSucc) {
            battle.doBattle(this.dataGetter, battle.getStartTime());
         } else {
            ErrorSceneLog.getInstance().appendErrorMsg("removeBattle battle fail").appendBattleId(battle.getBattleId()).appendPlayerId(player.getPlayerId()).appendPlayerName(player.getPlayerName()).appendClassName("JuBenService").appendMethodName("clearOneSideOfBattle").flush();
         }
      }

   }

   private int caculatePhantomCopperExp(int playerId, JuBenDto juBenDto) {
      if (juBenDto != null && !this.isInWorldDrama(playerId)) {
         return 0;
      } else {
         AddExpInfo expResult = null;

         try {
            double copperSum = 0.0;
            double chiefExpSum = 0.0;
            Map<Integer, Double> gExpMap = new HashMap();
            Iterator var10 = juBenDto.juBenCityDtoMap.values().iterator();

            int addGExp;
            while(var10.hasNext()) {
               JuBenCityDto juBenCityDto = (JuBenCityDto)var10.next();
               int cityId = juBenCityDto.cityId;
               List<ScenarioNpc> list = this.dataGetter.getScenarioNpcDao().getByPlayerIdLocationId(playerId, cityId);
               Iterator var14 = list.iterator();

               while(var14.hasNext()) {
                  ScenarioNpc scenarioNpc = (ScenarioNpc)var14.next();
                  if (scenarioNpc.getNpcType() == 1) {
                     PlayerGeneralMilitary pgm = this.dataGetter.getPlayerGeneralMilitaryDao().read(scenarioNpc.getArmyId());
                     if (pgm != null) {
                        addGExp = pgm.getGeneralId();
                        General general = (General)this.dataGetter.getGeneralCache().get(addGExp);
                        Troop troop = this.dataGetter.getTroopCache().getTroop(general.getTroop(), playerId);
                        int troopId = troop.getId();
                        double troopFoodConsumeCoe = ((TroopConscribe)this.dataGetter.getTroopConscribeCache().get(troopId)).getFood();
                        int hp = scenarioNpc.getHp();
                        double troopFood = troopFoodConsumeCoe * (double)hp;
                        double delta = troopFood * 0.28;
                        copperSum += delta;
                        double attTechAddGZJY = (double)this.dataGetter.getTechEffectCache().getTechEffect(playerId, 40) / 100.0;
                        double lgzexp = this.dataGetter.getBattleDataCache().getPlayerExpadd(playerId) / 100.0;
                        chiefExpSum += (1.0 + attTechAddGZJY + lgzexp) * delta;
                        double gExpAdd = (double)this.dataGetter.getTechEffectCache().getTechEffect(playerId, 16) / 100.0;
                        if (this.dataGetter.getPlayerDao().getConsumeLv(playerId) >= 9) {
                           gExpAdd += 0.1;
                        }

                        if (this.dataGetter.getPlayerDao().ismooncard(playerId)) {
                           gExpAdd += 0.15;
                        }

                        if (playerId > 0) {
                           Map<Integer, String> ycbweffectMap = this.dataGetter.getBattleDataCache().getYcbwMap(playerId, addGExp);
                           gExpAdd += Double.valueOf((String)ycbweffectMap.get(8)) / 100.0;
                        }

                        if (playerId > 0) {
                           Date firstbufftime = this.dataGetter.getPlayerAttributeDao().read(playerId).getHuiYuanTime();
                           if (firstbufftime != null && System.currentTimeMillis() < firstbufftime.getTime() + 7200000L) {
                              ++gExpAdd;
                           }
                        }

                        double gExp = (1.0 + gExpAdd) * delta;
                        Double gExpSum = (Double)gExpMap.get(addGExp);
                        if (gExpSum == null) {
                           gExpMap.put(addGExp, gExp);
                        } else {
                           gExpMap.put(addGExp, gExpSum + gExp);
                        }
                     }
                  }
               }
            }

            if (copperSum == 0.0 && chiefExpSum == 0.0 && gExpMap.size() == 0) {
               return 0;
            } else {
               if (copperSum > 0.0) {
                  this.dataGetter.getPlayerResourceDao().addCopperIgnoreMax(playerId, copperSum, "剧本结束，折算幻影获得银币", true);
               }

               if (chiefExpSum > 0.0) {
                  expResult = this.dataGetter.getPlayerService().updateExpAndPlayerLevel(playerId, (long)((int)chiefExpSum), "剧本结束，折算幻影增加经验", new int[0]);
               }

               StringBuilder content = new StringBuilder();
               String jubenName = LocalMessages.DANREN_JUEBN_NAME;
               if (this.isWorldDrama(juBenDto.juBen_id)) {
                  jubenName = LocalMessages.WORLD_DRAMA_NAME;
               }

               content.append(MessageFormatter.format(LocalMessages.JIEBING_FANHUAN_FORMAT_PART1, new Object[]{jubenName, (int)copperSum, expResult.addExp}));
               Iterator var41 = gExpMap.entrySet().iterator();

               while(true) {
                  int gId;
                  List gExpUpList;
                  do {
                     int gExp2;
                     do {
                        if (!var41.hasNext()) {
                           this.dataGetter.getMailService().writeSystemMail(LocalMessages.T_MAIL_ROLE_SYSTEM, LocalMessages.JIEBING_FANHUAN_TITLE, content.toString(), 1, playerId, new Date());
                           return expResult == null ? 0 : (int)expResult.addExp;
                        }

                        Map.Entry<Integer, Double> entry = (Map.Entry)var41.next();
                        gId = (Integer)entry.getKey();
                        gExp2 = ((Double)entry.getValue()).intValue();
                     } while(gExp2 <= 0);

                     gExpUpList = this.dataGetter.getGeneralService().updateExpAndGeneralLevel(playerId, gId, (long)gExp2);
                  } while(gExpUpList == null);

                  addGExp = 0;

                  UpdateExp ue;
                  for(Iterator var47 = gExpUpList.iterator(); var47.hasNext(); addGExp += (int)ue.getCurExp()) {
                     ue = (UpdateExp)var47.next();
                  }

                  String gName = ((General)this.dataGetter.getGeneralCache().get(gId)).getName();
                  content.append(MessageFormatter.format(LocalMessages.JIEBING_FANHUAN_FORMAT_PART2, new Object[]{gName, addGExp}));
               }
            }
         } catch (Exception var36) {
            Exception e = var36;
            ErrorSceneLog.getInstance().error("JuBenService.caculatePhantomCopperExp Exception", e);
            return expResult == null ? 0 : (int)expResult.addExp;
         }
      }
   }

   public void juBenDeal(String param) {
      int playerId = Integer.valueOf(param);
      JuBenDto juBenDto = JuBenManager.getInstance().getByPid(Integer.valueOf(param));
      if (juBenDto != null) {
         synchronized(juBenDto) {
            if (juBenDto.state == 0) {
               return;
            }

            if (juBenDto.star <= 1) {
               this.juBenOver(playerId, juBenDto, false);
            } else if (System.currentTimeMillis() >= juBenDto.endTime) {
               --juBenDto.star;
               juBenDto.addTime = 0L;
               Map<Integer, SoloReward> srMap = this.soloRewardCache.getBySoloId(juBenDto.juBen_id, juBenDto.grade);
               long addTime = (long)((SoloReward)srMap.get(juBenDto.star)).getReqTime();
               juBenDto.endTime += addTime * 1000L;
               this.playerScenarioDao.updateStar(playerId, juBenDto.juBen_id, juBenDto.star, new Date(juBenDto.endTime));
               this.jobService.addJob("juBenService", "juBenDeal", String.valueOf(playerId), juBenDto.endTime, false);
               JsonDocument doc = new JsonDocument();
               doc.startObject();
               doc.createElement("title", juBenDto.title);
               long time = juBenDto.endTime - System.currentTimeMillis();
               doc.createElement("time", time > 0L ? time : 0L);
               doc.createElement("addTime", addTime);
               doc.createElement("addStar", -1);
               doc.createElement("grade", juBenDto.grade);
               doc.createElement("star", juBenDto.star);
               doc.createElement("target", juBenDto.target);
               doc.endObject();
               Players.push(playerId, PushCommand.PUSH_JUBEN_INFO, doc.toByte());
            }
         }
      }

   }

   @Transactional
   public void addEndTime(int playerId, long addTime) {
      JuBenDto juBenDto = JuBenManager.getInstance().getByPid(playerId);
      if (juBenDto != null) {
         Date date = new Date();
         Map<Integer, SoloReward> srMap = this.soloRewardCache.getBySoloId(juBenDto.juBen_id, juBenDto.grade);
         long curStarMaxTime = (long)((SoloReward)srMap.get(juBenDto.star)).getReqTime() * 1000L;
         long curStarLeftTime = juBenDto.endTime - date.getTime();
         long curStarPassTime = curStarMaxTime - curStarLeftTime;
         long addTimeCopy = addTime;
         long endTime = 0L;
         int addStar = 0;

         do {
            if (juBenDto.star >= 5) {
               long maxTime = date.getTime() + (long)((SoloReward)srMap.get(5)).getReqTime() * 1000L;
               endTime = juBenDto.endTime + addTime;
               if (endTime > maxTime) {
                  endTime = maxTime;
               }

               addTime = 0L;
               break;
            }

            if (addTime <= curStarPassTime) {
               endTime = juBenDto.endTime + addTime;
               addTime = 0L;
               break;
            }

            ++juBenDto.star;
            ++addStar;
            addTime -= curStarPassTime;
            endTime = date.getTime() + curStarMaxTime;
            curStarMaxTime = curStarPassTime = (long)((SoloReward)srMap.get(juBenDto.star)).getReqTime() * 1000L;
            juBenDto.endTime = date.getTime();
         } while(addTime > 0L);

         juBenDto.endTime = endTime;
         this.playerScenarioDao.updateEndTimeCurStar(playerId, juBenDto.juBen_id, juBenDto.star, new Date(juBenDto.endTime));
         this.jobService.addJob("juBenService", "juBenDeal", String.valueOf(playerId), juBenDto.endTime, false);
         JsonDocument doc = new JsonDocument();
         doc.startObject();
         doc.createElement("title", juBenDto.title);
         long time = juBenDto.endTime - System.currentTimeMillis();
         doc.createElement("time", time > 0L ? time : 0L);
         doc.createElement("addTime", addTimeCopy / 1000L);
         doc.createElement("addStar", addStar);
         doc.createElement("grade", juBenDto.grade);
         doc.createElement("star", juBenDto.star);
         doc.createElement("target", juBenDto.target);
         doc.endObject();
         Players.push(playerId, PushCommand.PUSH_JUBEN_INFO, doc.toByte());
      }
   }

   @Transactional
   public byte[] enterJuBenQuick(PlayerDto playerDto, Request request) {
      int playerId = playerDto.playerId;
      JuBenDto juBenDto = JuBenManager.getInstance().getByPid(playerId);
      return juBenDto != null ? this.enterJuBenScene(playerDto, juBenDto.juBen_id, juBenDto.grade, 0, 0, 0, request) : JsonBuilder.getJson(State.FAIL, LocalMessages.JUBEN_CANNT_QUIT);
   }

   @Transactional
   public byte[] juBenPermit(PlayerDto playerDto, int sId, int grade, int create, Request request) {
      int playerId = playerDto.playerId;
      JuBenDto juBenDto = JuBenManager.getInstance().getByPid(playerId);
      if (juBenDto != null) {
         return JsonBuilder.getJson(State.SUCCESS, "");
      } else {
         List<PlayerGeneralMilitary> pgmList = this.playerGeneralMilitaryDao.getMilitaryList(playerId);
         PlayerScenario ps = this.playerScenarioDao.getScenarioByPidSid(playerId, sId);
         if (ps == null) {
            return JsonBuilder.getJson(State.FAIL, LocalMessages.T_COMM_10020);
         } else if (ps != null && ps.getState() == 0 && create == 0) {
            JsonDocument doc1 = new JsonDocument();
            doc1.startObject();
            doc1.createElement("inJuBen", false);
            doc1.endObject();
            Players.push(playerId, PushCommand.PUSH_UPDATE, doc1.toByte());
            return JsonBuilder.getJson(State.FAIL, "");
         } else {
            String[] starLvs = ps.getStarlv().split(",");
            if (grade - 1 > 0 && Integer.valueOf(starLvs[grade - 2]) < 4) {
               return JsonBuilder.getJson(State.FAIL, LocalMessages.JUBEN_NOT_OPEN_JUBEN_LV);
            } else {
               boolean canAtt = true;
               Map<Integer, SoloReward> soloReward = this.soloRewardCache.getBySoloId(sId, grade);
               SoloReward reward = (SoloReward)soloReward.get(1);
               if (reward != null) {
                  int food = reward.getReqFood();
                  PlayerResource playerResource = this.playerResourceDao.read(playerId);
                  if (playerResource != null && playerResource.getFood() < (long)food) {
                     return JsonBuilder.getJson(State.FAIL, LocalMessages.T_COMM_10027);
                  }
               }

               boolean isSoloDrama = !this.isInWorldDrama(playerId);
               Iterator var16 = pgmList.iterator();

               int forcesMax;
               PlayerGeneralMilitary pgm;
               do {
                  if (!var16.hasNext()) {
                     Set<Team> teamSet = TeamManager.getInstance().getJoinTeam(playerId);
                     Set<Integer> set = new HashSet();
                     if (teamSet != null) {
                        Iterator var29 = teamSet.iterator();

                        label90:
                        while(true) {
                           List giList;
                           do {
                              do {
                                 Team team;
                                 do {
                                    if (!var29.hasNext()) {
                                       break label90;
                                    }

                                    team = (Team)var29.next();
                                 } while(team.getMemberMap().get(playerId) == null);

                                 giList = ((TeamMember)team.getMemberMap().get(playerId)).getGeneralInfo();
                              } while(giList == null);
                           } while(giList.size() <= 0);

                           Iterator var21 = giList.iterator();

                           while(var21.hasNext()) {
                              GeneralInfo gi = (GeneralInfo)var21.next();
                              set.add(gi.getGeneralId());
                           }
                        }
                     }

                     if (set.size() > 0) {
                        return JsonBuilder.getJson(State.FAIL, LocalMessages.JUBEN_CANNT_JOIN_GENREAL_BUSY);
                     }

                     return JsonBuilder.getJson(State.SUCCESS, "");
                  }

                  pgm = (PlayerGeneralMilitary)var16.next();
                  if (pgm.getState() > 1) {
                     return JsonBuilder.getJson(State.FAIL, LocalMessages.JUBEN_CANNT_JOIN_GENREAL_BUSY);
                  }

                  GeneralMoveDto generalMoveDto = CityService.getGeneralMoveDto(playerId, pgm.getGeneralId());
                  if (generalMoveDto != null) {
                     int var18 = generalMoveDto.cityState;
                  }

                  GeneralMoveDto gmd = CityService.getGeneralMoveDto(pgm.getPlayerId(), pgm.getGeneralId());
                  if (gmd != null && (gmd.cityState == 22 || gmd.cityState == 23)) {
                     return JsonBuilder.getJson(State.FAIL, LocalMessages.GENERAL_IN_CELL);
                  }

                  forcesMax = this.battleDataCache.getMaxHp(pgm);
               } while(!isSoloDrama || pgm.getForces() >= forcesMax);

               return JsonBuilder.getJson(State.FAIL, LocalMessages.JUBEN_FORCES_NOT_FULL);
            }
         }
      }
   }

   @Transactional
   public byte[] getJuBenScene(PlayerDto playerDto, int sId, int grade, Request request) {
      JsonDocument doc = new JsonDocument();
      doc.startObject();
      SoloDrama soloDrama = (SoloDrama)this.soloDramaCache.get(sId);
      if (soloDrama == null) {
         return JsonBuilder.getJson(State.FAIL, LocalMessages.T_COMM_10011);
      } else {
         doc.createElement("sId", sId);
         doc.createElement("title", soloDrama.getName());
         Map<Integer, SoloReward> srMap = this.soloRewardCache.getBySoloId(sId, grade);
         long time = (long)(((SoloReward)srMap.get(5)).getReqTime() * 1000);
         doc.createElement("time", time > 0L ? time : 0L);
         doc.createElement("grade", grade);
         doc.createElement("target", soloDrama.getPlot());
         doc.startArray("cities");
         Map<Integer, SoloCity> map = this.soloCityCache.getBySoloId(sId);
         int npcCapital = 0;
         int myCapital = 0;
         Iterator var14 = map.values().iterator();

         while(var14.hasNext()) {
            SoloCity bcd = (SoloCity)var14.next();
            if (bcd.getCapital() == 1) {
               if (bcd.getBelong() == 1) {
                  npcCapital = bcd.getId();
               } else {
                  myCapital = bcd.getId();
               }
            }

            doc.startObject();
            doc.createElement("cityId", bcd.getId());
            doc.createElement("name", bcd.getName());
            int belong = bcd.getBelong();
            doc.createElement("forceId", belong == 0 ? playerDto.forceId : (belong >= 101 ? belong : 0));
            doc.createElement("terrain", bcd.getTerrain());
            doc.endObject();
         }

         doc.endArray();
         doc.createElement("capital", myCapital);
         doc.createElement("targetCityId", npcCapital);
         doc.endObject();
         return JsonBuilder.getJson(State.SUCCESS, doc.toByte());
      }
   }

   @Transactional
   public byte[] enterJuBenScene(PlayerDto playerDto, int sId, int grade, int create, int groupId, int followGeneral, Request request) {
      int playerId = playerDto.playerId;
      int xingrade = grade;
      if (grade == 0) {
         JuBenDto juBentemp = JuBenManager.getInstance().getByPid(playerId);
         if (juBentemp == null) {
            this.cacheJuBen(playerId, sId);
            xingrade = 1;
         } else {
            xingrade = juBentemp.grade;
         }
      }

      List<PlayerGeneralMilitary> pgmList = this.playerGeneralMilitaryDao.getMilitaryList(playerId);
      int jubenLoId;
      if (this.isWorldDrama(sId)) {
         WdSjp wdSjp = (WdSjp)this.dataGetter.getWdSjpCache().get(5);
         int perDayMax = wdSjp.getNumMax();
         PlayerBattleAttribute pba = this.dataGetter.getPlayerBattleAttributeDao().read(playerDto.playerId);
         int todayCount = pba.getEventWorldDramaCountToday();
         if (todayCount >= perDayMax) {
            return JsonBuilder.getJson(State.FAIL, LocalMessages.PLAYER_EVENT_REACH_COUNT_LIMIT);
         }

         WorldDramaTimesCache cache = WorldDramaTimesCache.getInstatnce();
         WdSjpDrama worldDrama = this.dataGetter.getWdSjpDramaCache().getWorldDramaByDramaIdAndGrade(sId, xingrade);
         if (worldDrama == null) {
            return JsonBuilder.getJson(State.FAIL, LocalMessages.T_COMM_10011);
         }

         jubenLoId = cache.getTimesByPIDAndSIdAndGrade(playerDto.playerId, worldDrama.getDramaId(), worldDrama.getDifficulty());
         if (jubenLoId >= worldDrama.getNumMax()) {
            return JsonBuilder.getJson(State.FAIL, LocalMessages.PLAYER_EVENT_REACH_COUNT_LIMIT);
         }
      }

      JuBenDto juBenDto = JuBenManager.getInstance().getByPid(playerId);
      boolean isFirst = false;
      Iterator var21;
      if (juBenDto == null) {
         isFirst = true;
         PlayerScenario ps = this.playerScenarioDao.getScenarioByPidSid(playerId, sId);
         boolean canAtt;
         if (ps == null) {
            canAtt = false;
            return JsonBuilder.getJson(State.FAIL, LocalMessages.T_COMM_10020);
         }

         if (ps != null && ps.getState() == 0 && create == 0) {
            JsonDocument doc1 = new JsonDocument();
            doc1.startObject();
            doc1.createElement("inJuBen", false);
            doc1.endObject();
            Players.push(playerId, PushCommand.PUSH_UPDATE, doc1.toByte());
            return JsonBuilder.getJson(State.FAIL, "");
         }

         canAtt = true;
         WdSjpDrama drama = this.wdSjpDramaCache.getWorldDramaByDramaId(sId);
         int locationId = (Integer)WorldCityCommon.nationMainCityIdMap.get(playerDto.forceId);
         jubenLoId = 0;
         Map<Integer, SoloCity> map = this.soloCityCache.getBySoloId(sId);
         Iterator var20 = map.values().iterator();

         while(var20.hasNext()) {
            SoloCity sc = (SoloCity)var20.next();
            if (sc.getCapital() == 1 && sc.getBelong() == 0) {
               jubenLoId = sc.getId();
            }
         }

         boolean isSoloDrama = !this.isInWorldDrama(playerId);
         var21 = pgmList.iterator();

         int food;
         while(var21.hasNext()) {
            PlayerGeneralMilitary pgm = (PlayerGeneralMilitary)var21.next();
            if (pgm.getState() > 1) {
               return JsonBuilder.getJson(State.FAIL, LocalMessages.JUBEN_CANNT_JOIN_GENREAL_BUSY);
            }

            food = this.battleDataCache.getMaxHp(pgm);
            if (isSoloDrama && pgm.getForces() < food) {
               return JsonBuilder.getJson(State.FAIL, LocalMessages.JUBEN_FORCES_NOT_FULL);
            }
         }

         Map<Integer, SoloReward> soloReward = this.soloRewardCache.getBySoloId(sId, xingrade);
         if (soloReward != null) {
            SoloReward reward = (SoloReward)soloReward.get(1);
            food = reward.getReqFood();
            if (!this.playerResourceDao.consumeFood(playerId, food, "进入普通剧本消耗粮食")) {
               return JsonBuilder.getJson(State.FAIL, LocalMessages.T_COMM_10027);
            }
         }

         Set<Team> teamSet = TeamManager.getInstance().getJoinTeam(playerId);
         Set<Integer> set = new HashSet();
         if (teamSet != null) {
            Iterator var24 = teamSet.iterator();

            label213:
            while(true) {
               List giList;
               do {
                  do {
                     Team team;
                     do {
                        if (!var24.hasNext()) {
                           break label213;
                        }

                        team = (Team)var24.next();
                     } while(team.getMemberMap().get(playerId) == null);

                     giList = ((TeamMember)team.getMemberMap().get(playerId)).getGeneralInfo();
                  } while(giList == null);
               } while(giList.size() <= 0);

               Iterator var27 = giList.iterator();

               while(var27.hasNext()) {
                  GeneralInfo gi = (GeneralInfo)var27.next();
                  set.add(gi.getGeneralId());
               }
            }
         }

         if (set.size() > 0) {
            return JsonBuilder.getJson(State.FAIL, LocalMessages.JUBEN_CANNT_JOIN_GENREAL_BUSY);
         }

         if (ps.getState() == 0) {
            String[] starLvs = ps.getStarlv().split(",");
            if (drama == null && xingrade - 1 > 0 && Integer.valueOf(starLvs[xingrade - 2]) < 4) {
               return JsonBuilder.getJson(State.FAIL, LocalMessages.JUBEN_NOT_OPEN_JUBEN_LV);
            }

            int res = this.playerGeneralMilitaryDao.updateJuBenLocation(playerId, locationId, jubenLoId);
            if (res != pgmList.size()) {
               return JsonBuilder.getJson(State.FAIL, LocalMessages.JUBEN_CANNT_JOIN_GENREAL_BUSY);
            }

            this.updateJuBen(playerId, sId, xingrade);
            this.initJuBenNpcs(playerDto, sId, xingrade);
         }

         this.generalService.sendGeneralMilitaryList(playerId);
         pgmList = this.playerGeneralMilitaryDao.getMilitaryList(playerId);
         JsonDocument doc2 = new JsonDocument();
         doc2.startObject();
         doc2.createElement("inJuBen", true);
         doc2.endObject();
         Players.push(playerId, PushCommand.PUSH_UPDATE, doc2.toByte());
         juBenDto = this.cacheJuBen(playerId, sId);
      }

      JsonDocument doc3 = new JsonDocument();
      doc3.startObject();
      doc3.createElement("type", 1);
      doc3.createElement("title", juBenDto.title);
      long time = juBenDto.endTime - System.currentTimeMillis();
      doc3.createElement("time", time > 0L ? time : 0L);
      doc3.createElement("grade", juBenDto.grade);
      doc3.createElement("capital", juBenDto.capital);
      doc3.createElement("star", juBenDto.star);
      doc3.createElement("target", juBenDto.target);
      doc3.createElement("targetCityId", juBenDto.npcCapital);
      doc3.createElement("state", juBenDto.state);
      if (juBenDto.state == 0) {
         doc3.createElement("win", juBenDto.isWin);
      }

      doc3.startArray("cities");
      int canAtt2 = false;
      Iterator var41 = juBenDto.juBenCityDtoMap.values().iterator();

      while(var41.hasNext()) {
         JuBenCityDto bcd = (JuBenCityDto)var41.next();
         doc3.startObject();
         doc3.createElement("cityId", bcd.cityId);
         doc3.createElement("name", bcd.cityName);
         doc3.createElement("forceId", bcd.forceId);
         doc3.createElement("state", bcd.state);
         doc3.createElement("terrain", bcd.terrain);
         if (juBenDto.capital == bcd.cityId) {
            doc3.createElement("nameId", 0);
         } else {
            doc3.createElement("nameId", bcd.title);
         }

         this.getTrickInfo(doc3, bcd.trickDto, playerDto.forceId, bcd.cityId);
         int canAtt2 = 0;
         if (bcd.forceId != playerDto.forceId) {
            Set<Integer> roadSet = this.soloRoadCache.getNeighbors(bcd.cityId);
            var21 = roadSet.iterator();

            while(var21.hasNext()) {
               Integer key = (Integer)var21.next();
               if (((JuBenCityDto)juBenDto.juBenCityDtoMap.get(key)).forceId == playerDto.forceId) {
                  canAtt2 = 1;
                  break;
               }
            }
         }

         doc3.createElement("canAtt", Integer.valueOf(canAtt2));
         if (juBenDto.cityChangeMap != null) {
            Integer cityType = (Integer)juBenDto.cityChangeMap.get(bcd.cityId);
            if (cityType != null) {
               doc3.createElement("newAppearanceType", cityType);
            }
         }

         doc3.startArray("armyType");
         doc3.endArray();
         doc3.endObject();
      }

      doc3.endArray();
      List<PlayerGeneralCivil> pgcList = this.playerGeneralCivilDao.getCivilListOrderByLv(playerId);
      doc3.startArray("stratagem");
      Iterator var48 = pgcList.iterator();

      while(var48.hasNext()) {
         PlayerGeneralCivil pgc = (PlayerGeneralCivil)var48.next();
         General general = (General)this.generalCache.get(pgc.getGeneralId());
         Stratagem stratagem = (Stratagem)this.stratagemCache.get(general.getStratagemId());
         if (stratagem != null) {
            doc3.startObject();
            TrickFactory.getTrickInfo(doc3, stratagem);
            doc3.createElement("stratagemId", stratagem.getId());
            doc3.createElement("cilvilId", general.getId());
            doc3.createElement("pic", general.getPic());
            if (pgc.getCd() != null) {
               long cd = pgc.getCd().getTime() - (new Date()).getTime();
               doc3.createElement("cd", cd > 0L ? cd : 0L);
            }

            doc3.createElement("stratagemIntro", stratagem.getIntro());
            doc3.endObject();
         }
      }

      doc3.endArray();
      long curTime = System.currentTimeMillis();
      int followgeneral = 0;
      String followpic = "";
      doc3.startArray("generalPaths");
      double percentPath = 0.0;
      Iterator var65 = pgmList.iterator();

      while(var65.hasNext()) {
         PlayerGeneralMilitary pgm2 = (PlayerGeneralMilitary)var65.next();
         GeneralMoveDto gmd = CityService.getGeneralMoveDto(playerId, pgm2.getGeneralId());
         if (gmd != null && gmd.nextMoveTime > curTime && gmd.type == 2) {
            doc3.startObject();
            doc3.createElement("generalId", pgm2.getGeneralId());
            doc3.createElement("startCityId", gmd.startCityId);
            percentPath = 0.0;
            if (gmd.nextMoveTime > curTime) {
               percentPath = (double)(curTime - gmd.startMoveTime) * 1.0 / (double)(gmd.nextMoveTime - gmd.startMoveTime);
               percentPath = Math.ceil(percentPath * 100.0) / 100.0;
            }

            doc3.createElement("percent", percentPath);
            doc3.appendJson(this.getMovePath(pgm2.getJubenLoId(), gmd.moveLine));
            doc3.endObject();
         } else {
            doc3.startObject();
            doc3.createElement("generalId", pgm2.getGeneralId());
            doc3.createElement("startCityId", pgm2.getJubenLoId());
            doc3.endObject();
         }

         if (followgeneral <= 0) {
            followgeneral = pgm2.getGeneralId();
            followpic = ((General)this.generalCache.get(pgm2.getGeneralId())).getPic();
         }
      }

      doc3.endArray();
      if (isFirst) {
         this.sendFirstEnterJubenDialog(doc3, juBenDto, playerId);
      }

      if (juBenDto.mengdeLocation > 0) {
         doc3.createElement("mengdeLocation", juBenDto.mengdeLocation);
      }

      doc3.createElement("isSafe", juBenDto.isMengdeSafe);
      this.scenarioEventManager.getPlayerScenarioEventInfo(playerId, doc3);
      doc3.endObject();
      return JsonBuilder.getJson(State.SUCCESS, doc3.toByte());
   }

   private void sendFirstEnterJubenDialog(JsonDocument doc, JuBenDto juBenDto, int playerId) {
      if (juBenDto.juBen_id == 1) {
         doc.createElement("dialogId", 1);
      } else if (juBenDto.juBen_id == 9) {
         if (juBenDto.grade == 1) {
            ScenarioEventJsonBuilder.sendDialog(playerId, 9006, (Object)null);
         } else if (juBenDto.grade != 2 && juBenDto.grade != 3) {
            if (juBenDto.grade == 4) {
               ScenarioEventJsonBuilder.sendDialog(playerId, 9008, (Object)null);
            } else if (juBenDto.grade == 5) {
               ScenarioEventJsonBuilder.sendDialog(playerId, 9009, (Object)null);
            }
         } else {
            ScenarioEventJsonBuilder.sendDialog(playerId, 9007, (Object)null);
         }
      } else if (juBenDto.juBen_id == 11 && juBenDto.grade == 1) {
         ScenarioEventJsonBuilder.sendDialog(playerId, 11002, (Object)null);
      }

   }

   private void getTrickInfo(JsonDocument doc, HashMap<Integer, HashMap<String, TrickDto>> trickDto, int forceId, int cityId) {
      if (trickDto != null) {
         doc.createElement("cityId", cityId);
         doc.startArray("trickState");
         Iterator var6 = trickDto.keySet().iterator();

         label75:
         while(true) {
            HashMap map;
            do {
               if (!var6.hasNext()) {
                  doc.endArray();
                  return;
               }

               Integer index = (Integer)var6.next();
               map = (HashMap)trickDto.get(index);
            } while(map == null);

            Iterator var9 = map.keySet().iterator();

            while(true) {
               String type;
               TrickDto dto;
               long now;
               long lastTime;
               long protectTime;
               do {
                  do {
                     do {
                        if (!var9.hasNext()) {
                           continue label75;
                        }

                        type = (String)var9.next();
                        dto = (TrickDto)map.get(type);
                     } while(dto == null);
                  } while(!type.equalsIgnoreCase("kongcheng") && !type.equalsIgnoreCase("huogong") && !type.equalsIgnoreCase("shuigong") && !type.equalsIgnoreCase("luoshi") && dto.getForceId() != forceId);

                  now = System.currentTimeMillis();
                  lastTime = dto.getLastTime();
                  protectTime = dto.getProtectTime();
               } while(lastTime <= now && protectTime <= now);

               doc.startObject();
               doc.createElement("stratagemId", dto.getId());
               doc.createElement("type", dto.getType());
               doc.createElement("lv", dto.getLv());
               if (protectTime > now) {
                  doc.createElement("protectCd", protectTime - now);
               }

               if (lastTime > now) {
                  doc.createElement("lastTime", lastTime - now);
                  if (type.equalsIgnoreCase("guwu") || type.equalsIgnoreCase("dongyao")) {
                     Stratagem stratagem = (Stratagem)this.stratagemCache.get(dto.getId());
                     doc.createElement("stateValue", stratagem.getPar1());
                  }
               }

               doc.endObject();
            }
         }
      }
   }

   private byte[] getMovePath(int cityId, String moveLine) {
      JsonDocument doc = new JsonDocument();
      doc.startArray("path");
      doc.startObject();
      doc.createElement("cityId", cityId);
      doc.endObject();
      if (!StringUtils.isEmpty(moveLine)) {
         String[] cityIds = moveLine.split(",");

         for(int i = 0; i < cityIds.length; ++i) {
            String id = cityIds[i];
            doc.startObject();
            doc.createElement("cityId", id);
            doc.endObject();
         }
      }

      doc.endArray();
      return doc.toByte();
   }

   @Transactional
   public byte[] autoMoveJuBenStop(PlayerDto playerDto, int generalId) {
      int playerId = playerDto.playerId;
      PlayerGeneralMilitary pgm = this.playerGeneralMilitaryDao.getMilitary(playerId, generalId);
      GeneralMoveDto gmd = CityService.getGeneralMoveDto(playerId, generalId);
      if (gmd == null) {
         return JsonBuilder.getJson(State.FAIL, "");
      } else if (gmd.cityState != 6) {
         gmd.moveLine = "";
         return JsonBuilder.getJson(State.FAIL, "");
      } else {
         JsonDocument doc = new JsonDocument();
         doc.startObject();
         gmd.moveLine = "";
         this.generalService.sendGeneralMilitaryRecruitInfo(playerId, pgm);
         this.generalService.sendGenerlJuBenMoveInfo(playerId, generalId);
         doc.endObject();
         return JsonBuilder.getJson(State.SUCCESS, doc.toByte());
      }
   }

   public byte[] autoMoveJuBen(int playerId, int cityId, int generalId) {
      JuBenDto juBenDto = JuBenManager.getInstance().getByPid(playerId);
      if (juBenDto != null && juBenDto.juBenCityDtoMap != null) {
         synchronized(((JuBenCityDto)juBenDto.juBenCityDtoMap.get(cityId)).battleId) {
            Player player = this.playerDao.read(playerId);
            PlayerGeneralMilitary pgm = this.playerGeneralMilitaryDao.getMilitary(playerId, generalId);
            if (pgm == null) {
               return JsonBuilder.getJson(State.FAIL, LocalMessages.T_NO_SUCH_GENERAL_MOVE);
            } else {
               int curId = pgm.getJubenLoId();
               SoloRoad soloRoad = this.soloRoadCache.getRoad(juBenDto.juBen_id, curId, cityId);
               if (soloRoad != null && juBenDto.roadLinked != null && juBenDto.roadLinked.contains(soloRoad.getId())) {
                  return JsonBuilder.getJson(State.FAIL, LocalMessages.MOVE_AUTO_NO_ROAD);
               } else {
                  int state = pgm.getState();
                  if (state != 0 && state != 1) {
                     return JsonBuilder.getJson(State.FAIL, LocalMessages.GENERAL_BUSY);
                  } else {
                     boolean adjoining = false;
                     Set<Integer> nbSet = this.soloRoadCache.getNeighbors(pgm.getJubenLoId());
                     Iterator var14 = nbSet.iterator();

                     while(var14.hasNext()) {
                        Integer key = (Integer)var14.next();
                        if (key == cityId) {
                           adjoining = true;
                        }
                     }

                     JuBenCityDto targetCity = (JuBenCityDto)juBenDto.juBenCityDtoMap.get(cityId);
                     GeneralMoveDto gmd = CityService.getGeneralMoveDto(playerId, generalId);
                     if (gmd != null && CDUtil.isInCD(gmd.nextMoveTime, new Date())) {
                        if (pgm.getJubenLoId() == cityId) {
                           gmd.moveLine = "";
                           this.generalService.sendGenerlJuBenMoveInfo(playerId, generalId);
                           return JsonBuilder.getJson(State.FAIL, "");
                        }
                     } else {
                        String battleId = NewBattleManager.getBattleId(18, playerId, cityId);
                        Battle battle = NewBattleManager.getInstance().getBattleByBatId(battleId);
                        if ((targetCity.forceId != player.getForceId() || battle != null) && adjoining) {
                           OperationResult result = this.dataGetter.getCilvilTrickService().hasTrick(targetCity);
                           if (result != null && !result.getResult()) {
                              return JsonBuilder.getJson(State.FAIL, result.getResultContent());
                           }

                           gmd = CityService.getGeneralMoveDto(playerId, generalId);
                           if (gmd != null && CDUtil.isInCD(gmd.nextMoveTime, new Date())) {
                              return JsonBuilder.getJson(State.FAIL, LocalMessages.GENERAL_IN_MOVE_CD);
                           }

                           int maxHp = this.dataGetter.getBattleDataCache().getMaxHp(pgm);
                           if ((double)pgm.getForces() * 1.0 / (double)maxHp < 0.05) {
                              return JsonBuilder.getJson(State.FAIL, LocalMessages.BATTLE_INT_BATTLE_BLOOD_NO_ENOUGH);
                           }

                           SoloCity sc = (SoloCity)this.soloCityCache.get(cityId);
                           this.battleService.battleStart(playerId, 18, cityId, String.valueOf(generalId), sc.getTerrain());
                           this.sendAttMoveInfo(playerId, generalId, pgm.getJubenLoId(), cityId, player.getForceId(), "", (long)pgm.getForces(), false);
                           gmd = CityService.getGeneralMoveDto(playerId, generalId);
                           if (gmd != null) {
                              gmd.moveLine = "";
                           }

                           JsonDocument doc = new JsonDocument();
                           doc.startObject();
                           doc.createElement("endCityId", cityId);
                           doc.endObject();
                           return JsonBuilder.getJson(State.SUCCESS, doc.toByte());
                        }
                     }

                     Set<Integer> setTemp = new HashSet();
                     setTemp.add(cityId);
                     setTemp.add(pgm.getJubenLoId());
                     Iterator var33 = juBenDto.juBenCityDtoMap.values().iterator();

                     while(var33.hasNext()) {
                        JuBenCityDto temp = (JuBenCityDto)var33.next();
                        if (temp.forceId == player.getForceId()) {
                           setTemp.add(temp.cityId);
                        }
                     }

                     int[] arr = new int[setTemp.size()];
                     int j = 0;

                     for(Iterator var37 = setTemp.iterator(); var37.hasNext(); ++j) {
                        Integer key2 = (Integer)var37.next();
                        arr[j] = key2;
                     }

                     int[] x = null;
                     int[] y = null;

                     try {
                        if (juBenDto.roadLinked != null && !juBenDto.roadLinked.isEmpty()) {
                           int size = juBenDto.roadLinked.size();
                           x = new int[size];
                           y = new int[size];
                           int i = 0;
                           Iterator var23 = juBenDto.roadLinked.iterator();

                           while(var23.hasNext()) {
                              Integer roadId = (Integer)var23.next();
                              SoloRoad road = (SoloRoad)this.soloRoadCache.get(roadId);
                              if (road != null) {
                                 x[i] = road.getStart();
                                 y[i] = road.getEnd();
                                 ++i;
                              }
                           }
                        }
                     } catch (Exception var26) {
                        errorLog.error(this, var26);
                     }

                     List<Integer> list = this.juBenDataCache.getMinPathJuBen(juBenDto.juBen_id, pgm.getJubenLoId(), cityId, arr, x, y);
                     if (list != null && list.size() > 0) {
                        StringBuilder sb = new StringBuilder();

                        for(int k = 1; k < list.size(); ++k) {
                           sb.append(list.get(k)).append(",");
                        }

                        JsonDocument doc2 = new JsonDocument();
                        doc2.startObject();
                        gmd = CityService.getUpdateGeneralMoveDto(playerId, generalId);
                        gmd.type = 2;
                        gmd.moveLine = sb.toString();
                        if (sb.length() <= 0) {
                           this.generalService.sendGeneralMilitaryRecruitInfo(playerId, pgm);
                           this.generalService.sendGenerlJuBenMoveInfo(playerId, generalId);
                        }

                        gmd.cityState = 6;
                        if (gmd != null && gmd.nextMoveTime > System.currentTimeMillis()) {
                           doc2.startArray("path");
                           Iterator var48 = list.iterator();

                           while(var48.hasNext()) {
                              int id2 = (Integer)var48.next();
                              doc2.startObject();
                              doc2.createElement("cityId", id2);
                              doc2.endObject();
                           }

                           doc2.endArray();
                           this.generalService.sendGenerlJuBenMoveInfo(playerId, generalId);
                        } else {
                           Tuple<Integer, String> tupleMove = this.move(playerId, generalId, (Integer)list.get(1), true);
                           if ((Integer)tupleMove.left != 6 && (Integer)tupleMove.left != 1) {
                              return JsonBuilder.getJson(State.FAIL, (String)tupleMove.right);
                           }

                           if ((Integer)tupleMove.left == 6) {
                              doc2.startArray("path");
                              Iterator var25 = list.iterator();

                              while(var25.hasNext()) {
                                 int id = (Integer)var25.next();
                                 doc2.startObject();
                                 doc2.createElement("cityId", id);
                                 doc2.endObject();
                              }

                              doc2.endArray();
                              this.generalService.sendGenerlJuBenMoveInfo(playerId, generalId);
                           }
                        }

                        doc2.createElement("endCityId", cityId);
                        doc2.endObject();
                        return JsonBuilder.getJson(State.SUCCESS, doc2.toByte());
                     } else {
                        return JsonBuilder.getJson(State.FAIL, LocalMessages.MOVE_AUTO_NO_ROAD);
                     }
                  }
               }
            }
         }
      } else {
         return JsonBuilder.getJson(State.FAIL, "你已不在剧本中....");
      }
   }

   public Tuple<Integer, String> move(int playerId, int generalId, int cityId, boolean auto) {
      JuBenDto juBenDto = JuBenManager.getInstance().getByPid(playerId);
      synchronized(((JuBenCityDto)juBenDto.juBenCityDtoMap.get(cityId)).battleId) {
         Tuple<Integer, String> tupleMove = new Tuple();
         Player player = this.playerDao.read(playerId);
         PlayerGeneralMilitary pgm = this.playerGeneralMilitaryDao.getMilitary(playerId, generalId);
         Set<Integer> neighbors = this.soloRoadCache.getNeighbors(pgm.getJubenLoId());
         if (!neighbors.isEmpty() && neighbors.contains(cityId)) {
            int curId = pgm.getJubenLoId();
            SoloRoad soloRoad = this.soloRoadCache.getRoad(juBenDto.juBen_id, curId, cityId);
            if (soloRoad != null && juBenDto.roadLinked != null && juBenDto.roadLinked.contains(soloRoad.getId())) {
               GeneralMoveDto gmd2 = CityService.getGeneralMoveDto(playerId, generalId);
               if (gmd2 != null) {
                  gmd2.moveLine = "";
               }

               tupleMove.left = 0;
               tupleMove.right = LocalMessages.MOVE_AUTO_NO_ROAD;
               return tupleMove;
            } else {
               String battleId = NewBattleManager.getBattleId(18, playerId, cityId);
               Battle battle = NewBattleManager.getInstance().getBattleByBatId(battleId);
               boolean adjoining = false;
               Set<Integer> nbSet = this.soloRoadCache.getNeighbors(pgm.getJubenLoId());
               Iterator var18 = nbSet.iterator();

               while(var18.hasNext()) {
                  Integer key = (Integer)var18.next();
                  if (key == cityId) {
                     adjoining = true;
                  }
               }

               JuBenCityDto targetCity = (JuBenCityDto)juBenDto.juBenCityDtoMap.get(cityId);
               GeneralMoveDto gmd3;
               if ((targetCity.forceId != player.getForceId() || battle != null) && adjoining) {
                  OperationResult result = this.dataGetter.getCilvilTrickService().hasTrick(targetCity);
                  if (result != null && !result.getResult()) {
                     tupleMove.left = 0;
                     tupleMove.right = result.getResultContent();
                     return tupleMove;
                  } else {
                     int maxHp = this.dataGetter.getBattleDataCache().getMaxHp(pgm);
                     if ((double)pgm.getForces() * 1.0 / (double)maxHp < 0.05) {
                        gmd3 = CityService.getGeneralMoveDto(playerId, generalId);
                        if (gmd3 != null) {
                           gmd3.moveLine = "";
                        }

                        tupleMove.left = 0;
                        tupleMove.right = LocalMessages.BATTLE_INT_BATTLE_BLOOD_NO_ENOUGH;
                        return tupleMove;
                     } else {
                        SoloCity sc = (SoloCity)this.soloCityCache.get(cityId);
                        this.battleService.battleStart(playerId, 18, cityId, String.valueOf(generalId), sc.getTerrain());
                        this.sendAttMoveInfo(playerId, generalId, pgm.getJubenLoId(), cityId, player.getForceId(), "", (long)pgm.getForces(), false);
                        GeneralMoveDto gmd4 = CityService.getGeneralMoveDto(playerId, generalId);
                        if (gmd4 != null) {
                           gmd4.moveLine = "";
                        }

                        tupleMove.left = 1;
                        tupleMove.right = LocalMessages.CITY_IN_BATTLEING;
                        return tupleMove;
                     }
                  }
               } else {
                  Tuple<Integer, String> tuple = this.checkMoveCondition(pgm, player, cityId, auto);
                  if ((Integer)tuple.left != 1) {
                     if ((Integer)tuple.left != 6) {
                        GeneralMoveDto gmd5 = CityService.getGeneralMoveDto(playerId, generalId);
                        if (gmd5 != null) {
                           gmd5.moveLine = "";
                        }
                     }

                     this.generalService.sendGeneralMilitaryRecruitInfo(playerId, pgm);
                     tupleMove.left = (Integer)tuple.left;
                     tupleMove.right = (String)tuple.right;
                     return tupleMove;
                  } else {
                     this.startMove(playerId, generalId, cityId, auto);
                     StringBuilder sb = new StringBuilder();
                     gmd3 = CityService.getGeneralMoveDto(playerId, generalId);
                     if (gmd3 != null && gmd3.moveLine != null && gmd3.moveLine.length() > 0) {
                        String[] strs = gmd3.moveLine.split(",");

                        for(int i = 1; i < strs.length; ++i) {
                           if (i > 1 || cityId != Integer.valueOf(strs[i])) {
                              sb.append(strs[i]).append(",");
                           }
                        }

                        this.sendAttMoveInfo(playerId, generalId, pgm.getJubenLoId(), cityId, player.getForceId(), sb.toString(), (long)pgm.getForces(), false);
                        sb = this.updateMoveLine(gmd3.moveLine, cityId);
                        gmd3.moveLine = sb.toString();
                        if (sb.length() <= 0) {
                           gmd3.moveLine = "";
                        }

                        gmd3.cityState = 6;
                     }

                     tupleMove.left = 1;
                     tupleMove.right = "";
                     return tupleMove;
                  }
               }
            }
         } else {
            GeneralMoveDto gmd = CityService.getGeneralMoveDto(playerId, generalId);
            if (gmd != null) {
               gmd.moveLine = "";
            }

            tupleMove.left = 0;
            tupleMove.right = LocalMessages.LOCATION_NOT_NEIGHBOR;
            return tupleMove;
         }
      }
   }

   private StringBuilder updateMoveLine(String moveLine, int cityId) {
      StringBuilder sb = new StringBuilder();
      String[] strs = moveLine.split(",");

      for(int i = 1; i < strs.length; ++i) {
         if (i > 1 || cityId != Integer.valueOf(strs[i])) {
            sb.append(strs[i]).append(",");
         }
      }

      return sb;
   }

   private Tuple<Integer, String> checkMoveCondition(PlayerGeneralMilitary pgm, Player player, int cityId, boolean auto) {
      Tuple<Integer, String> tuple = new Tuple();
      if (pgm == null) {
         tuple.left = 2;
         tuple.right = LocalMessages.T_NO_SUCH_GENERAL_MOVE;
         return tuple;
      } else {
         int playerId = pgm.getPlayerId();
         Date nowDate = new Date();
         int state = pgm.getState();
         if (state != 0 && state != 1) {
            tuple.left = 5;
            tuple.right = LocalMessages.GENERAL_BUSY;
            return tuple;
         } else {
            GeneralMoveDto gmd = CityService.getGeneralMoveDto(playerId, pgm.getGeneralId());
            if (gmd != null && CDUtil.isInCD(gmd.nextMoveTime, nowDate)) {
               tuple.left = 6;
               tuple.right = LocalMessages.GENERAL_IN_MOVE_CD;
               return tuple;
            } else {
               JuBenDto juBenDto = JuBenManager.getInstance().getByPid(playerId);
               JuBenCityDto targetCity = (JuBenCityDto)juBenDto.juBenCityDtoMap.get(cityId);
               if (targetCity.forceId != player.getForceId()) {
                  tuple.left = 7;
                  tuple.right = LocalMessages.FORCE_WRONG;
                  return tuple;
               } else {
                  Set<Integer> neighbors = this.soloRoadCache.getNeighbors(pgm.getJubenLoId());
                  if (!neighbors.isEmpty() && neighbors.contains(cityId)) {
                     tuple.left = 1;
                     return tuple;
                  } else {
                     tuple.left = 8;
                     tuple.right = LocalMessages.LOCATION_NOT_NEIGHBOR;
                     return tuple;
                  }
               }
            }
         }
      }
   }

   public boolean startMove(int playerId, int generalId, int cityId, boolean auto) {
      PlayerGeneralMilitary pgm = this.playerGeneralMilitaryDao.getMilitary(playerId, generalId);
      Player player = this.playerDao.read(playerId);
      int state = pgm.getState();
      int curCityId = pgm.getJubenLoId();
      JuBenDto juBenDto = JuBenManager.getInstance().getByPid(playerId);
      if (juBenDto == null) {
         return false;
      } else {
         SoloRoad road = this.soloRoadCache.getRoad(juBenDto.juBen_id, curCityId, cityId);
         long cd = 0L;
         General general = (General)this.generalCache.get(pgm.getGeneralId());
         Troop troop = this.troopCache.getTroop(general.getTroop(), player.getPlayerId());
         cd = WorldCityCommon.getNextMoveCd(road.getLength(), (float)troop.getSpeed());
         if (this.playerDao.getConsumeLv(playerId) >= 8) {
            cd = Double.valueOf((double)cd / 1.2).longValue();
         }

         if (player.getHuiYuan1() > 0 && player.getHuiYuan1Time().after(new Date())) {
            cd = Double.valueOf((double)(cd / 2L)).longValue();
         }

         Map<Integer, String> ycbweffectMap = this.battleDataCache.getYcbwMap(playerId, generalId);
         cd = Double.valueOf((double)cd / (1.0 + Double.valueOf((String)ycbweffectMap.get(9)) / 100.0)).longValue();
         int mingjuadd = this.battleDataCache.getGeneralHorseLeader(playerId, generalId);
         if (mingjuadd > 0) {
            cd = Double.valueOf((double)cd / 1.2).longValue();
         }

         Date nextMoveDate = new Date(System.currentTimeMillis() + cd);
         boolean isRecruiting = state == 1;
         String params = WorldCityCommon.makeTaskParam(playerId, generalId, isRecruiting, auto);
         StringBuffer sb = new StringBuffer(params);
         sb.append(";").append(cityId);
         long nextMoveTime = nextMoveDate.getTime();
         int taskId = this.jobService.addJob("juBenService", "changeState", sb.toString(), nextMoveTime + 1000L);
         GeneralMoveDto gmd = CityService.getUpdateGeneralMoveDto(playerId, generalId);
         gmd.startMoveTime = System.currentTimeMillis();
         gmd.startCityId = curCityId;
         gmd.cityState = 6;
         gmd.nextMoveTime = nextMoveTime;
         gmd.taskId = taskId;
         gmd.type = 2;
         this.playerGeneralMilitaryDao.moveJuben(playerId, generalId, state, cityId);
         this.generalService.sendGeneralMilitaryRecruitInfo(playerId, generalId);
         this.generalService.sendGenerlJuBenMoveInfo(playerId, generalId);
         ScenarioEventMessageHelper.sendMoveToCitykMessage(playerId, generalId, cityId);
         return true;
      }
   }

   public void changeState(String param) {
      String[] s = param.split(";");
      int playerId = Integer.valueOf(s[0]);
      int generalId = Integer.valueOf(s[1]);
      boolean wasRecruiting = Integer.valueOf(s[2]) == 1;
      boolean auto = Integer.valueOf(s[3]) == 1;
      PlayerGeneralMilitary pgm = this.playerGeneralMilitaryDao.getMilitary(playerId, generalId);
      if (pgm != null) {
         GeneralMoveDto gmd = CityService.getUpdateGeneralMoveDto(playerId, generalId);
         synchronized(gmd) {
            if (gmd.nextMoveTime == 0L || System.currentTimeMillis() < gmd.nextMoveTime) {
               return;
            }

            gmd.nextMoveTime = 0L;
            gmd.type = 2;
         }

         if (!auto || !this.inAutoMove(playerId, generalId)) {
            gmd.cityState = 0;
            gmd.nextMoveTime = 0L;
            if (pgm.getState() == 1 || pgm.getState() == 0) {
               Date nowDate = new Date();
               if (wasRecruiting) {
                  this.playerGeneralMilitaryDao.restartRecruit(playerId, generalId, 1, nowDate);
               }
            }

            this.generalService.sendGeneralMilitaryRecruitInfo(playerId, generalId);
            this.generalService.sendGenerlJuBenMoveInfo(playerId, generalId);
         }
      }
   }

   public boolean inAutoMove(int playerId, int generalId) {
      PlayerGeneralMilitary pgm = this.playerGeneralMilitaryDao.getMilitary(playerId, generalId);
      GeneralMoveDto gmd = CityService.getGeneralMoveDto(playerId, generalId);
      if (gmd != null && gmd.moveLine != null && gmd.moveLine.length() > 0) {
         String[] strs = gmd.moveLine.split(",");
         if (strs.length > 0) {
            int cityId = Integer.valueOf(strs[0]);
            if (cityId == pgm.getJubenLoId()) {
               if (strs.length <= 1) {
                  gmd.moveLine = "";
                  this.generalService.sendGeneralMilitaryRecruitInfo(playerId, pgm);
                  this.generalService.sendGenerlJuBenMoveInfo(playerId, generalId);
                  return false;
               }

               cityId = Integer.valueOf(strs[1]);
            }

            Tuple<Integer, String> tupleMove = this.move(playerId, generalId, cityId, true);
            if ((Integer)tupleMove.left != 1) {
               gmd.moveLine = "";
               this.generalService.sendGeneralMilitaryRecruitInfo(playerId, pgm.getGeneralId());
               this.generalService.sendGenerlJuBenMoveInfo(playerId, generalId);
            }

            return true;
         }

         gmd.moveLine = "";
         this.generalService.sendGeneralMilitaryRecruitInfo(playerId, pgm.getGeneralId());
         this.generalService.sendGenerlJuBenMoveInfo(playerId, generalId);
      }

      return false;
   }

   public void sendAttMoveInfo(int playerId, int generalId, int cityId, int nextCityId, int forceId, String moveLine, long forceShow, boolean atOnce) {
      JsonDocument doc = new JsonDocument();
      doc.startObject();
      doc.createElement("generalId", generalId);
      doc.createElement("orgCityId", cityId);
      doc.createElement("curCityId", nextCityId);
      doc.createElement("atOnce", atOnce);
      doc.createElement("id", nextCityId);
      if (cityId != nextCityId) {
         doc.appendJson(this.getMovePath(cityId, nextCityId, moveLine));
      }

      GeneralMoveDto gmd = CityService.getGeneralMoveDto(playerId, generalId);
      if (gmd != null && gmd.nextMoveTime > 0L) {
         doc.createElement("cd", CDUtil.getCD(gmd.nextMoveTime, new Date()));
      }

      if (!StringUtils.isEmpty(moveLine)) {
         doc.createElement("autoMove", true);
      }

      doc.endObject();
      Players.push(playerId, PushCommand.PUSH_ATTMOV_JUBEN, doc.toByte());
   }

   private byte[] getMovePath(int orgCityId, int cityId, String moveLine) {
      JsonDocument doc = new JsonDocument();
      doc.startArray("path");
      doc.startObject();
      doc.createElement("cityId", orgCityId);
      doc.endObject();
      doc.startObject();
      doc.createElement("cityId", cityId);
      doc.endObject();
      if (!StringUtils.isEmpty(moveLine)) {
         String[] cityIds = moveLine.split(",");

         for(int i = 0; i < cityIds.length; ++i) {
            String id = cityIds[i];
            doc.startObject();
            doc.createElement("cityId", Integer.valueOf(id));
            doc.endObject();
         }
      }

      doc.endArray();
      return doc.toByte();
   }

   public void changeForceIdAndState(int cityId, int forceId, int state, int playerId, String playerName) {
      try {
         JuBenDto juBenDto = JuBenManager.getInstance().getByPid(playerId);
         if (juBenDto != null) {
            JuBenCityDto city = (JuBenCityDto)juBenDto.juBenCityDtoMap.get(cityId);
            city.state = 0;
            city.forceId = forceId;
            this.playerScenarioCityDao.updateForceId(playerId, juBenDto.juBen_id, cityId, forceId, juBenDto.player_force_id);
            ScenarioEventMessageHelper.sendCityStateChangeMessage(cityId, state, playerId);
            Map<Integer, Integer> changeMap = new HashMap();
            int orgTitle = city.title;
            int surroundTitle = this.getSurroundState(juBenDto, city);
            if (orgTitle != surroundTitle && city.cityId != juBenDto.npcCapital && juBenDto.juBen_id != 10 && !this.isWorldDrama(juBenDto.juBen_id)) {
               city.title = surroundTitle;
               changeMap.put(city.cityId, surroundTitle);
            }

            JuBenCityDto ci = null;
            Set<Integer> set = this.soloRoadCache.getNeighbors(cityId);
            Iterator var14 = set.iterator();

            while(true) {
               int subSurroundTitle;
               do {
                  if (!var14.hasNext()) {
                     Players.push(playerId, PushCommand.PUSH_JUBEN, JsonBuilder.getSimpleJson("refresh", true));
                     return;
                  }

                  Integer cId = (Integer)var14.next();
                  ci = (JuBenCityDto)juBenDto.juBenCityDtoMap.get(cId);
                  orgTitle = ci.title;
                  subSurroundTitle = this.getSurroundState(juBenDto, ci);
               } while(orgTitle == subSurroundTitle && ci.cityId != juBenDto.capital);

               if (ci.cityId != juBenDto.npcCapital && juBenDto.juBen_id != 10 && !this.isWorldDrama(juBenDto.juBen_id)) {
                  ci.title = subSurroundTitle;
                  changeMap.put(ci.cityId, subSurroundTitle);
               }

               Set<Integer> subSet = this.soloRoadCache.getNeighbors(ci.cityId);
               JuBenCityDto subCi = null;
               int subOrgTitle = false;
               Iterator var20 = subSet.iterator();

               while(var20.hasNext()) {
                  Integer subCId = (Integer)var20.next();
                  if (subCId != city.cityId) {
                     subCi = (JuBenCityDto)juBenDto.juBenCityDtoMap.get(subCId);
                     if (subCi.forceId == ci.forceId) {
                        int subOrgTitle = subCi.title;
                        int thirdSurroundState = this.getSurroundState(juBenDto, ci);
                        if (subOrgTitle != thirdSurroundState && subCi.cityId != juBenDto.npcCapital && juBenDto.juBen_id != 10 && !this.isWorldDrama(juBenDto.juBen_id)) {
                           subCi.title = thirdSurroundState;
                           changeMap.put(subCi.cityId, thirdSurroundState);
                        }
                     }
                  }
               }
            }
         }
      } catch (Exception var22) {
         Exception e = var22;
         errorLog.error("CityService, modify city force and state exception.", e);
      }
   }

   private boolean isWorldDrama(int jubenId) {
      return this.wdSjpDramaCache.getWorldDramaByDramaId(jubenId) != null;
   }

   private int getSurroundState(JuBenDto juBenDto, JuBenCityDto city) {
      Set<Integer> set = this.soloRoadCache.getNeighbors(city.cityId);
      JuBenCityDto ci = null;
      int sameForceNum = 0;
      JuBenCityDto sameForceCity = null;
      Iterator var8 = set.iterator();

      Integer subCi;
      while(var8.hasNext()) {
         subCi = (Integer)var8.next();
         ci = (JuBenCityDto)juBenDto.juBenCityDtoMap.get(subCi);
         if (city.forceId == ci.forceId) {
            ++sameForceNum;
            sameForceCity = ci;
         }
      }

      if (sameForceNum == 0) {
         return 1;
      } else if (sameForceNum == 1) {
         subCi = null;
         Set<Integer> subSet = this.soloRoadCache.getNeighbors(sameForceCity.cityId);
         Iterator var10 = subSet.iterator();

         while(var10.hasNext()) {
            Integer subCId = (Integer)var10.next();
            if (subCId != city.cityId) {
               JuBenCityDto subCi = (JuBenCityDto)juBenDto.juBenCityDtoMap.get(subCId);
               if (city.forceId == subCi.forceId) {
                  return 0;
               }
            }
         }

         return 2;
      } else {
         return 0;
      }
   }

   private void clearJubBenOver(JuBenDto juBenDto, int playerId) {
      Player player = this.dataGetter.getPlayerDao().read(playerId);
      List<PlayerGeneralMilitary> pgmList = this.playerGeneralMilitaryDao.getMilitaryList(playerId);
      int forcesMax = false;
      int needForces = false;
      Iterator var8 = pgmList.iterator();

      while(var8.hasNext()) {
         PlayerGeneralMilitary pgm = (PlayerGeneralMilitary)var8.next();
         GeneralMoveDto gmd = CityService.getGeneralMoveDto(playerId, pgm.getGeneralId());
         if (gmd != null && gmd.type == 2) {
            gmd.moveLine = "";
            this.generalService.sendGeneralMilitaryRecruitInfo(playerId, pgm);
            this.generalService.sendGenerlJuBenMoveInfo(playerId, pgm.getGeneralId());
         }

         if (!this.isInWorldDrama(playerId)) {
            int forcesMax = this.battleDataCache.getMaxHp(pgm);
            int needForces = forcesMax - pgm.getForces();
            if (needForces > 0) {
               this.playerGeneralMilitaryDao.addGeneralForces(playerId, pgm.getGeneralId(), new Date(), 0, (long)needForces);
            }
         }
      }

      int capitalId = juBenDto.capital;
      Iterator var16 = juBenDto.juBenCityDtoMap.values().iterator();

      while(true) {
         JuBenCityDto jbcd;
         do {
            if (!var16.hasNext()) {
               this.generalService.sendGeneralMilitaryList(playerId);
               return;
            }

            jbcd = (JuBenCityDto)var16.next();
         } while(jbcd.cityId == juBenDto.capital);

         this.clearBattlesInThisCity(player, jbcd, true);
         Iterator var11 = pgmList.iterator();

         while(var11.hasNext()) {
            PlayerGeneralMilitary pgm2 = (PlayerGeneralMilitary)var11.next();
            if (pgm2.getJubenLoId() == jbcd.cityId) {
               this.dataGetter.getPlayerGeneralMilitaryDao().moveJuben(pgm2.getPlayerId(), pgm2.getGeneralId(), 1, capitalId);
               ScenarioEventMessageHelper.sendMoveToCitykMessage(pgm2.getPlayerId(), pgm2.getGeneralId(), capitalId);
            }
         }

         this.dataGetter.getScenarioNpcDao().deleteAllInThisCity(playerId, jbcd.cityId);
      }
   }

   private void clearBattlesInThisCity(Player player, JuBenCityDto juBenCityDto, boolean playerSide) {
      try {
         Battle battle = NewBattleManager.getInstance().getBattleByBatId(juBenCityDto.battleId);
         if (battle != null) {
            this.clearOneSideOfBattle(player, juBenCityDto, battle, playerSide);
         }

         List<Battle> oneToOneBattleList = NewBattleManager.getInstance().getAllScenariosOneToOneBattle(player.getPlayerId(), juBenCityDto.cityId);
         if (oneToOneBattleList != null && oneToOneBattleList.size() > 0) {
            Iterator var7 = oneToOneBattleList.iterator();

            while(var7.hasNext()) {
               Battle oneToOneBattle = (Battle)var7.next();
               this.clearOneSideOfBattle(player, juBenCityDto, oneToOneBattle, playerSide);
            }
         }

         Builder scenarioEventBuilder = BuilderFactory.getInstance().getBuilder(20);
         String scenarioEventBattleId = scenarioEventBuilder.getBattleId(this.dataGetter, player, juBenCityDto.cityId);
         Battle scenarioEventBattle = NewBattleManager.getInstance().getBattleByBatId(scenarioEventBattleId);
         if (scenarioEventBattle != null) {
            this.clearOneSideOfBattle(player, juBenCityDto, scenarioEventBattle, playerSide);
         }
      } catch (Exception var9) {
         Exception e = var9;
         ErrorSceneLog.getInstance().error("JuBenService.clearBattlesInThisCity catch Exception", e);
      }

   }

   public byte[] quitJuBen(PlayerDto playerDto) {
      int playerId = playerDto.playerId;
      JuBenDto juBenDto = JuBenManager.getInstance().getByPid(playerId);
      if (juBenDto == null) {
         return JsonBuilder.getJson(State.FAIL, LocalMessages.JUBEN_CANNT_QUIT);
      } else {
         juBenDto.state = 0;
         juBenDto.isWin = false;

         try {
            this.caculatePhantomCopperExp(playerId, juBenDto);
            this.clearJubBenOver(juBenDto, playerId);
         } catch (Exception var6) {
            Exception e = var6;
            errorLog.error("JuBenService quitJuBen playerId " + playerId, e);
         }

         JuBenManager.getInstance().clearByVid(playerId);
         this.playerScenarioDao.updateStateOverTime(playerId, juBenDto.juBen_id, 0, System.currentTimeMillis());
         this.scenarioNpcDao.deleteAll(playerId);
         JsonDocument doc1 = new JsonDocument();
         doc1.startObject();
         doc1.createElement("inJuBen", false);
         doc1.endObject();
         Players.push(playerId, PushCommand.PUSH_UPDATE, doc1.toByte());
         if (this.isWorldDrama(juBenDto.juBen_id)) {
            WdSjp wdSjp = (WdSjp)this.dataGetter.getWdSjpCache().get(5);
            if (wdSjp != null) {
               this.dataGetter.getCityService().addPlayerNextEvent(playerDto.playerId, playerDto.forceId, 5, false);
            }
         }

         JsonDocument doc2 = new JsonDocument();
         doc2.startObject();
         doc2.createElement("quit", true);
         doc2.endObject();
         return JsonBuilder.getJson(State.SUCCESS, doc2.toByte());
      }
   }

   public byte[] pleaseGiveMeAReply(PlayerDto playerDto, int generalId) {
      PlayerGeneralMilitary pgm = this.playerGeneralMilitaryDao.getMilitary(playerDto.playerId, generalId);
      if (pgm == null) {
         return JsonBuilder.getJson(State.FAIL, "");
      } else {
         GeneralMoveDto gmd = CityService.getGeneralMoveDto(pgm.getPlayerId(), pgm.getGeneralId());
         if (gmd != null && !StringUtils.isBlank(gmd.moveLine)) {
            if (gmd.type != 2) {
               return JsonBuilder.getJson(State.FAIL, "");
            } else {
               String[] split = gmd.moveLine.split(",");
               if (split.length > 0) {
                  boolean isRecruiting = pgm.getState() == 1;
                  String params = WorldCityCommon.makeTaskParam(playerDto.playerId, generalId, isRecruiting, true);
                  StringBuffer sb = new StringBuffer(params);
                  sb.append(";").append(pgm.getLocationId());
                  this.jobService.addJob("juBenService", "changeState", sb.toString(), gmd.nextMoveTime);
               }

               return JsonBuilder.getJson(State.SUCCESS, "");
            }
         } else {
            return JsonBuilder.getJson(State.FAIL, "");
         }
      }
   }

   public Tuple<Boolean, String> assembleMove(int playerId, int generalId, int cityId, int kick) {
      Tuple<Boolean, String> tuple = new Tuple();
      JuBenDto juBenDto = JuBenManager.getInstance().getByPid(playerId);
      if (juBenDto == null) {
         tuple.left = false;
         tuple.right = LocalMessages.JUBEN_CANNT_QUIT;
         return tuple;
      } else {
         synchronized(((JuBenCityDto)juBenDto.juBenCityDtoMap.get(cityId)).battleId) {
            Player player = this.playerDao.read(playerId);
            PlayerGeneralMilitary pgm = this.playerGeneralMilitaryDao.getMilitary(playerId, generalId);
            if (pgm == null) {
               tuple.left = false;
               tuple.right = LocalMessages.T_NO_SUCH_GENERAL_MOVE;
               return tuple;
            } else {
               boolean adjoining = false;
               Set<Integer> nbSet = this.soloRoadCache.getNeighbors(pgm.getJubenLoId());
               Iterator var13 = nbSet.iterator();

               while(var13.hasNext()) {
                  Integer key = (Integer)var13.next();
                  if (key == cityId) {
                     adjoining = true;
                  }
               }

               JuBenCityDto targetCity = (JuBenCityDto)juBenDto.juBenCityDtoMap.get(cityId);
               GeneralMoveDto gmd;
               int state;
               if (targetCity.forceId != player.getForceId() && adjoining) {
                  state = this.dataGetter.getBattleDataCache().getMaxHp(pgm);
                  if ((double)pgm.getForces() * 1.0 / (double)state < 0.05) {
                     tuple.left = false;
                     tuple.right = LocalMessages.BATTLE_INT_BATTLE_BLOOD_NO_ENOUGH;
                     return tuple;
                  } else {
                     SoloCity sc = (SoloCity)this.soloCityCache.get(cityId);
                     this.battleService.battleStart(playerId, 18, cityId, String.valueOf(generalId), sc.getTerrain());
                     this.sendAttMoveInfo(playerId, generalId, pgm.getJubenLoId(), cityId, player.getForceId(), "", (long)pgm.getForces(), false);
                     gmd = CityService.getGeneralMoveDto(playerId, generalId);
                     if (gmd != null) {
                        gmd.moveLine = "";
                     }

                     tuple.left = true;
                     tuple.right = LocalMessages.CITY_IN_BATTLEING;
                     return tuple;
                  }
               } else {
                  state = pgm.getState();
                  if (state != 0 && state != 1) {
                     tuple.left = false;
                     tuple.right = LocalMessages.GENERAL_BUSY;
                     return tuple;
                  } else {
                     JuBenCityDto cityTemp = (JuBenCityDto)juBenDto.juBenCityDtoMap.get(pgm.getJubenLoId());
                     if (cityTemp.forceId != player.getForceId()) {
                        errorLog.error("JuBenService autoMove playerId:" + playerId + " playerForceId:" + player.getForceId() + " generalId:" + generalId + " pgm.getLocationId():" + pgm.getJubenLoId() + " targetCityId:" + cityId);
                     }

                     CityService.getGeneralMoveDto(playerId, generalId);
                     if (pgm.getJubenLoId() == cityId) {
                        tuple.left = false;
                        tuple.right = LocalMessages.GENERAL_IN_CURCITY_NO_MOVE;
                        return tuple;
                     } else {
                        Set<Integer> setTemp = new HashSet();
                        setTemp.add(cityId);
                        setTemp.add(pgm.getJubenLoId());
                        Iterator var18 = juBenDto.juBenCityDtoMap.values().iterator();

                        while(var18.hasNext()) {
                           JuBenCityDto temp = (JuBenCityDto)var18.next();
                           if (temp.forceId == player.getForceId()) {
                              setTemp.add(temp.cityId);
                           }
                        }

                        int[] arr = new int[setTemp.size()];
                        int j = 0;

                        for(Iterator var20 = setTemp.iterator(); var20.hasNext(); ++j) {
                           Integer key2 = (Integer)var20.next();
                           arr[j] = key2;
                        }

                        int[] x = null;
                        int[] y = null;

                        try {
                           if (juBenDto.roadLinked != null && !juBenDto.roadLinked.isEmpty()) {
                              int size = juBenDto.roadLinked.size();
                              x = new int[size];
                              y = new int[size];
                              int i = 0;
                              Iterator var24 = juBenDto.roadLinked.iterator();

                              while(var24.hasNext()) {
                                 Integer roadId = (Integer)var24.next();
                                 SoloRoad road = (SoloRoad)this.soloRoadCache.get(roadId);
                                 if (road != null) {
                                    x[i] = road.getStart();
                                    y[i] = road.getEnd();
                                    ++i;
                                 }
                              }
                           }
                        } catch (Exception var26) {
                           Exception e = var26;
                           errorLog.error(this, e);
                        }

                        List<Integer> list = this.juBenDataCache.getMinPathJuBen(juBenDto.juBen_id, pgm.getJubenLoId(), cityId, arr, x, y);
                        if (list != null && list.size() > 0) {
                           StringBuilder sb = new StringBuilder();

                           for(int k = 1; k < list.size(); ++k) {
                              sb.append(list.get(k)).append(",");
                           }

                           gmd = CityService.getUpdateGeneralMoveDto(playerId, generalId);
                           gmd.moveLine = sb.toString();
                           gmd.type = 1;
                           if (sb.length() <= 0) {
                              this.generalService.sendGeneralMilitaryRecruitInfo(playerId, pgm);
                              this.generalService.sendGenerlJuBenMoveInfo(playerId, generalId);
                           }

                           gmd.cityState = 6;
                           Tuple<Integer, String> tupleMove = this.move(playerId, generalId, (Integer)list.get(1), true);
                           if ((Integer)tupleMove.left != 6 && (Integer)tupleMove.left != 1) {
                              tuple.left = false;
                              tuple.right = (String)tupleMove.right;
                              return tuple;
                           } else {
                              if ((Integer)tupleMove.left == 6) {
                                 this.generalService.sendGenerlMoveInfo(playerId, generalId);
                              }

                              tuple.left = true;
                              tuple.right = LocalMessages.ASSEMBLE_SUCC;
                              return tuple;
                           }
                        } else {
                           tuple.left = false;
                           tuple.right = LocalMessages.MOVE_AUTO_NO_ROAD;
                           return tuple;
                        }
                     }
                  }
               }
            }
         }
      }
   }

   public void changeState(int playerId, int cityId, int state, boolean attWin) {
      JuBenDto juBenDto = JuBenManager.getInstance().getByPid(playerId);
      if (juBenDto != null) {
         JuBenCityDto jubenDto = (JuBenCityDto)juBenDto.juBenCityDtoMap.get(cityId);
         if (jubenDto == null) {
            errorLog.error("JubBenService changeState cityId:" + cityId);
         }

         jubenDto.state = state;
         ScenarioEventMessageHelper.sendCityStateChangeMessage(cityId, jubenDto.state = state, playerId);
         JsonDocument doc = new JsonDocument();
         doc.startObject();
         doc.startArray("cities");
         doc.startObject();
         doc.createElement("cityId", cityId);
         doc.createElement("state", state);
         doc.endObject();
         doc.endArray();
         doc.endObject();
         Players.push(playerId, PushCommand.PUSH_JUBEN_STATE, doc.toByte());
      }
   }

   public void dealTrap(Player player, PlayerGeneralMilitary pgm, int cityId) {
   }

   public byte[] getJuBenCityInfo(int cityId, PlayerDto playerDto) {
      JsonDocument doc = new JsonDocument();
      doc.startObject();
      JuBenDto juBenDto = JuBenManager.getInstance().getByPid(playerDto.playerId);
      if (juBenDto == null) {
         return JsonBuilder.getJson(State.FAIL, LocalMessages.JUBEN_NOT_IN_JUBEN);
      } else {
         JuBenCityDto jbcd = (JuBenCityDto)juBenDto.juBenCityDtoMap.get(cityId);
         if (jbcd == null) {
            return JsonBuilder.getJson(State.FAIL, LocalMessages.T_COMM_10012);
         } else {
            Battle battle = NewBattleManager.getInstance().getBattleByBatId(jbcd.battleId);
            if (battle != null) {
               doc.createElement("inBattle", true);
               boolean canWatchBat = true;
               doc.startArray("attSide");
               Iterator var9 = battle.attSideDetail.entrySet().iterator();

               Map.Entry entry;
               while(var9.hasNext()) {
                  entry = (Map.Entry)var9.next();
                  if ((Integer)entry.getValue() > 0) {
                     doc.startObject();
                     doc.createElement("forceId", entry.getKey());
                     doc.createElement("num", entry.getValue());
                     doc.endObject();
                  }
               }

               doc.endArray();
               doc.startArray("defSide");
               var9 = battle.defSideDetail.entrySet().iterator();

               while(var9.hasNext()) {
                  entry = (Map.Entry)var9.next();
                  if ((Integer)entry.getValue() > 0) {
                     doc.startObject();
                     doc.createElement("forceId", entry.getKey());
                     doc.createElement("num", entry.getValue());
                     doc.endObject();
                  }
               }

               doc.endArray();
               doc.createElement("battleId", battle.getBattleId());
               doc.createElement("targetId", battle.getDefBaseInfo().getId());
               doc.createElement("type", battle.getBattleType());
            } else {
               doc.createElement("inBattle", false);
            }

            this.getTrickInfo(doc, jbcd.trickDto, playerDto.forceId, jbcd.cityId);
            doc.endObject();
            return JsonBuilder.getJson(State.SUCCESS, doc.toByte());
         }
      }
   }

   public byte[] getChoiceInfo(PlayerDto playerDto, int eventId) {
      JuBenDto dto = JuBenManager.getInstance().getByPid(playerDto.playerId);
      if (dto == null) {
         return JsonBuilder.getJson(State.FAIL, LocalMessages.JUBEN_NOT_IN_JUBEN);
      } else {
         List<ScenarioEvent> list = dto.eventList;
         if (list == null) {
            return JsonBuilder.getJson(State.FAIL, LocalMessages.JUBEN_DEAL_CONDITION_NOT_FULFILL);
         } else {
            Iterator var6 = list.iterator();

            while(var6.hasNext()) {
               ScenarioEvent event = (ScenarioEvent)var6.next();
               if (event.getSoloEvent().getId() == eventId) {
                  if (event.getState() != 2) {
                     return JsonBuilder.getJson(State.FAIL, LocalMessages.JUBEN_EVENT_IS_COMPLETE);
                  }

                  ScenarioChoice choice = event.getChoice();
                  int cityId = choice.getChoiceCity();
                  String catogery = choice.getChoiceCatogery();
                  List<SoloCity> neighbours = null;
                  if (catogery.equalsIgnoreCase("dychoice")) {
                     neighbours = new ArrayList();
                     this.checkNeighbours(neighbours, dto);
                  }

                  int hasGeneralInCity = this.playerGeneralMilitaryDao.getGeneralNumInCity(playerDto.playerId, cityId);
                  if (hasGeneralInCity <= 0) {
                     return JsonBuilder.getJson(State.FAIL, LocalMessages.JUBEN_DEAL_CONDITION_NOT_FULFILL);
                  }

                  JuBenCityDto cityDto = (JuBenCityDto)dto.juBenCityDtoMap.get(cityId);
                  if (cityDto != null && cityDto.state == 0) {
                     JsonDocument doc = choice.getChoiceInfo(neighbours, dto.mengdeLocation);
                     if (doc != null) {
                        return JsonBuilder.getJson(State.SUCCESS, doc.toByte());
                     }

                     return JsonBuilder.getJson(State.FAIL, LocalMessages.JUBEN_DEAL_CONDITION_NOT_FULFILL);
                  }

                  return JsonBuilder.getJson(State.FAIL, LocalMessages.JUBEN_IS_FIGHTING);
               }
            }

            return JsonBuilder.getJson(State.FAIL, LocalMessages.JUBEN_DEAL_CONDITION_NOT_FULFILL);
         }
      }
   }

   private void checkNeighbours(List<SoloCity> neighbours, JuBenDto dto) {
      int location = dto.mengdeLocation;
      Set<Integer> result = this.dataGetter.getSoloRoadCache().getNeighbors(location);
      Iterator var6 = result.iterator();

      while(var6.hasNext()) {
         Integer key = (Integer)var6.next();
         SoloCity city = (SoloCity)this.soloCityCache.get(key);
         neighbours.add(city);
      }

   }

   public void saveEventInfo(int playerId) {
      JuBenDto dto = JuBenManager.getInstance().getByPid(playerId);
      if (dto != null) {
         List<ScenarioEvent> events = dto.eventList;
         if (events != null && !events.isEmpty()) {
            StringBuffer sb = new StringBuffer();

            try {
               Iterator var6 = events.iterator();

               while(var6.hasNext()) {
                  ScenarioEvent event = (ScenarioEvent)var6.next();
                  if (event != null) {
                     sb.append(event.selfStore()).append("+");
                  }
               }

               SymbolUtil.removeTheLast(sb);
               this.playerScenarioDao.updateScenarioInfo(playerId, dto.juBen_id, sb.toString());
            } catch (Exception var7) {
               Exception e = var7;
               errorLog.error("saveEventInfo fail...playerId:" + playerId);
               errorLog.error(e.getMessage());
               errorLog.error(this, e);
            }

         }
      }
   }

   public byte[] makeAChoice(int playerId, int eventId, int choice) {
      List<ScenarioEvent> list = null;
      JuBenDto dto = JuBenManager.getInstance().getByPid(playerId);
      if (dto == null) {
         return JsonBuilder.getJson(State.FAIL, "");
      } else {
         list = dto.eventList;
         if (list == null) {
            return JsonBuilder.getJson(State.FAIL, "");
         } else {
            SoloEvent soloEvent = (SoloEvent)this.soloEventCache.get(eventId);
            int cityId = this.getChoiceCity(soloEvent);
            String battleId = NewBattleManager.getBattleId(20, playerId, cityId);
            Battle battle = NewBattleManager.getInstance().getBattleByBatId(battleId);
            if (battle != null) {
               return JsonBuilder.getJson(State.FAIL, "");
            } else {
               ScenarioEvent temp = null;
               JsonDocument doc = null;
               Iterator var13 = list.iterator();

               while(true) {
                  if (var13.hasNext()) {
                     ScenarioEvent event = (ScenarioEvent)var13.next();
                     if (event.getSoloEvent().getId() != eventId) {
                        continue;
                     }

                     if (event.getState() >= 3 || event.getState() < 2) {
                        return JsonBuilder.getJson(State.FAIL, "");
                     }

                     ScenarioChoice scenarioChoice = event.getChoice();
                     if (scenarioChoice != null && event.getMainChoice() != 0 && !scenarioChoice.getHasFight()) {
                        temp = event;
                     }

                     event.setPlayerChoice(choice);
                     OperationResult result = this.doSpecialChoice(dto, scenarioChoice, choice, event, playerId);
                     if (!result.getResult()) {
                        return JsonBuilder.getJson(State.FAIL, result.getResultContent());
                     }

                     if (result.getExtraInfo() != null) {
                        doc = new JsonDocument();
                        doc.startObject();
                        doc.createElement("choice", result.getExtraInfo());
                        doc.endObject();
                     }
                  }

                  if (temp != null) {
                     this.makeAChoiceToTriggerOperation(playerId, eventId);
                  }

                  if (eventId == Constants.EVENT_ID_ANSHALIUZHANG_68 && choice == 1) {
                     ScenarioEventJsonBuilder.sendDialog(playerId, 8001, (Object)null);
                  } else if (eventId == Constants.EVENT_ID_JIXIZONGMIAO_170 && dto.grade >= 3) {
                     if (choice == 1) {
                        ScenarioEventJsonBuilder.sendDialog(playerId, 10011, (Object)null);
                     } else {
                        ScenarioEventJsonBuilder.sendDialog(playerId, 10012, (Object)null);
                     }
                  }

                  if (doc == null) {
                     return JsonBuilder.getJson(State.SUCCESS, "");
                  }

                  return JsonBuilder.getJson(State.SUCCESS, doc.toByte());
               }
            }
         }
      }
   }

   private OperationResult doSpecialChoice(JuBenDto dto, ScenarioChoice scenarioChoice, int choice, ScenarioEvent event, int playerId) {
      OperationResult result = new OperationResult(true);

      try {
         if (scenarioChoice != null) {
            String catogery = scenarioChoice.getChoiceCatogeryByChoice();
            int number;
            if (catogery.equalsIgnoreCase("multichoice")) {
               number = scenarioChoice.getMultiChoiceContent(choice);
               if (number >= 0) {
                  transferRoyalJade(dto, number);
                  event.setPlayerChoice(1);
               }
            } else if (catogery.equalsIgnoreCase("randchoice")) {
               number = scenarioChoice.getRandChoiceContent(choice);
               if (number <= 0) {
                  return result;
               }

               String costs = scenarioChoice.getCosts();
               int copper = Integer.parseInt(costs);
               if (!this.playerResourceDao.consumeCopper(playerId, copper, "剧本随机事件获取锦囊消耗银币")) {
                  result.setResult(false);
                  result.setResultContent(LocalMessages.T_COMM_10001);
               }

               int randInt = WebUtil.nextInt(number);
               event.setPlayerChoice(randInt + 1);
               String choice2 = scenarioChoice.getChoice1();
               String[] single = choice2.split(",");
               result.setExtraInfo(single[randInt + 1]);
            } else if (catogery.equalsIgnoreCase("dychoice")) {
               number = dto.mengdeLocation;
               Set<Integer> set = this.dataGetter.getSoloRoadCache().getNeighbors(number);
               if (set == null || !set.contains(choice)) {
                  return new OperationResult(false, LocalMessages.T_COMM_10011);
               }

               event.setPlayerChoice(choice);
            }
         }
      } catch (Exception var14) {
         Exception e = var14;
         errorLog.error(this, e);
         result.setResult(false);
         result.setResultContent(LocalMessages.T_COMM_10011);
      }

      return result;
   }

   private static void transferRoyalJade(JuBenDto dto, int multiChoice) {
      if (dto != null) {
         if ((dto.royalJadeBelong = multiChoice) == 0) {
            dto.royalEndTime = 0L;
         } else {
            dto.royalEndTime = System.currentTimeMillis() + 600000L;
         }

         JsonDocument doc = new JsonDocument();
         doc.startObject();
         doc.createElement("forceId", multiChoice);
         doc.createElement("endTime", dto.royalEndTime - System.currentTimeMillis());
         doc.endObject();
         Players.push(dto.player_id, PushCommand.PUSH_JUBEN_ROYALJADE_TRANSFER, doc.toByte());
      }
   }

   private int getChoiceCity(SoloEvent soloEvent) {
      if (soloEvent == null) {
         return 0;
      } else {
         try {
            String flag = soloEvent.getFlag2();
            if (StringUtils.isBlank(flag)) {
               return 0;
            } else {
               String[] single = flag.split(",");
               return Integer.parseInt(single[1]);
            }
         } catch (Exception var4) {
            Exception e = var4;
            errorLog.error("getChoiceCity fail...eventId" + soloEvent.getId());
            errorLog.error(e.getMessage());
            errorLog.error(this, e);
            return 0;
         }
      }
   }

   public void addNpcToCity(int playerId, int cityId, List<Tuple<Integer, Integer>> list, int camp) {
      try {
         if (list == null || list.isEmpty()) {
            return;
         }

         long start = System.currentTimeMillis();
         timeLog.info(LogUtil.formatThreadLog("JuBenService", "addNpcToCity", 0, 0L, "playerId:" + playerId + "cityId:" + cityId + "map:" + list.size() + "camp:" + camp));
         JuBenDto juBenDto = JuBenManager.getInstance().getByPid(playerId);
         if (juBenDto == null) {
            ErrorSceneLog.getInstance().appendErrorMsg("JuBenDto is null").append("playerId", playerId).append("cityId", cityId).append("map size", list.size()).appendClassName("JuBenService").appendMethodName("addNpcToCity").flush();
            return;
         }

         JuBenCityDto juBenCityDto = JuBenManager.getInstance().getJuBenCityDto(playerId, cityId);
         if (juBenCityDto == null) {
            ErrorSceneLog.getInstance().appendErrorMsg("JuBenCityDto is null").append("playerId", playerId).append("cityId", cityId).append("map size", list.size()).appendClassName("JuBenService").appendMethodName("addNpcToCity").flush();
            return;
         }

         if (camp == 0) {
            this.addNpcToCityForPlayer(playerId, cityId, list, juBenDto, juBenCityDto);
         } else {
            this.addNpcToCityForNpc(playerId, cityId, list, juBenDto, juBenCityDto, camp);
         }

         timeLog.info(LogUtil.formatThreadLog("JuBenService", "addNpcToCity", 2, System.currentTimeMillis() - start, "playerId:" + playerId + "cityId:" + cityId + "map size:" + list.size() + "camp:" + camp));
      } catch (Exception var9) {
         Exception e = var9;
         ErrorSceneLog.getInstance().error("JuBenService.addNpcToCity catch Exception", e);
      }

   }

   public static int changeForceId(int forceId) {
      return 105;
   }

   private void addNpcToCityForNpc(int playerId, int cityId, List<Tuple<Integer, Integer>> list, JuBenDto juBenDto, JuBenCityDto juBenCityDto, int camp) {
      try {
         Player player = this.dataGetter.getPlayerDao().read(playerId);
         int forceId = 0;
         if (camp == 4) {
            forceId = changeForceId(player.getForceId());
         } else if (camp >= 101) {
            forceId = camp;
         }

         int npcType = true;
         Date date = new Date();
         Builder builder = BuilderFactory.getInstance().getBuilder(18);
         String battleId = NewBattleManager.getBattleId(18, playerId, cityId);
         Battle juBenCityBattle = NewBattleManager.getInstance().getBattleByBatId(battleId);
         boolean state;
         LinkedList snList;
         Tuple general;
         Iterator var17;
         int armyId;
         int i;
         ScenarioNpc scenarioNpc;
         Army army;
         if (juBenCityBattle != null) {
            state = true;
            snList = new LinkedList();
            var17 = list.iterator();

            while(var17.hasNext()) {
               general = (Tuple)var17.next();
               armyId = (Integer)general.left;

               for(i = 0; i < (Integer)general.right; ++i) {
                  scenarioNpc = new ScenarioNpc();
                  scenarioNpc.setVId(scenarioNpcVId.incrementAndGet());
                  scenarioNpc.setPlayerId(playerId);
                  scenarioNpc.setScenarioId(juBenDto.juBen_id);
                  scenarioNpc.setLocationId(cityId);
                  scenarioNpc.setForceId(forceId);
                  scenarioNpc.setNpcType(2);
                  scenarioNpc.setArmyId(armyId);
                  army = (Army)this.dataGetter.getArmyCache().get(armyId);
                  scenarioNpc.setHp(army.getArmyHp());
                  scenarioNpc.setTacticVal(1);
                  scenarioNpc.setState(19);
                  scenarioNpc.setAddTime(date);
                  snList.add(scenarioNpc);
               }
            }

            this.dataGetter.getScenarioNpcDao().batchCreate(snList);
            int defForceId = juBenCityBattle.getDefBaseInfo().getForceId();
            int battleSide = true;
            byte battleSide;
            if (defForceId == forceId) {
               battleSide = 0;
            } else {
               battleSide = 1;
            }

            Iterator var31 = snList.iterator();

            while(var31.hasNext()) {
               ScenarioNpc scenarioNpc2 = (ScenarioNpc)var31.next();
               CampArmy tempEACa = builder.copyArmyFromScenarioNpc(this.dataGetter, player, juBenCityBattle, scenarioNpc2, battleSide);
               juBenCityBattle.joinCampArmy(this.dataGetter, battleSide, tempEACa, new int[0]);
            }
         } else if (juBenCityDto.forceId != forceId) {
            state = false;
            snList = new LinkedList();
            var17 = list.iterator();

            while(var17.hasNext()) {
               general = (Tuple)var17.next();
               armyId = (Integer)general.left;

               for(i = 0; i < (Integer)general.right; ++i) {
                  scenarioNpc = new ScenarioNpc();
                  scenarioNpc.setVId(scenarioNpcVId.incrementAndGet());
                  scenarioNpc.setPlayerId(playerId);
                  scenarioNpc.setScenarioId(juBenDto.juBen_id);
                  scenarioNpc.setLocationId(cityId);
                  scenarioNpc.setForceId(forceId);
                  scenarioNpc.setNpcType(2);
                  scenarioNpc.setArmyId(armyId);
                  army = (Army)this.dataGetter.getArmyCache().get(armyId);
                  scenarioNpc.setHp(army.getArmyHp());
                  scenarioNpc.setTacticVal(1);
                  scenarioNpc.setState(0);
                  scenarioNpc.setAddTime(date);
                  snList.add(scenarioNpc);
               }
            }

            this.dataGetter.getScenarioNpcDao().batchCreate(snList);
            Terrain terrain = builder.getTerrain(-1, cityId, this.dataGetter);
            juBenCityBattle = NewBattleManager.getInstance().createBattle(battleId);
            if (juBenCityBattle == null) {
               ErrorSceneLog.getInstance().appendErrorMsg("create battle fail").appendBattleId(battleId).append("playerId", playerId).append("cityId", cityId).append("map size", list.size()).appendClassName("JuBenService").appendMethodName("addNpcToCity").flush();
               return;
            }

            BattleAttacker battleAttacker = new BattleAttacker();
            battleAttacker.attType = 7;
            battleAttacker.attForceId = forceId;
            battleAttacker.attPlayerId = playerId;
            battleAttacker.attPlayer = player;
            juBenCityBattle.init(battleAttacker, 18, cityId, this.dataGetter, false, terrain.getValue());
            builder.dealUniqueStaff(this.dataGetter, juBenCityBattle, -1, cityId);
         } else {
            state = false;
            snList = new LinkedList();
            var17 = list.iterator();

            while(var17.hasNext()) {
               general = (Tuple)var17.next();
               armyId = (Integer)general.left;
               i = (Integer)general.right;

               for(int i = 0; i < i; ++i) {
                  ScenarioNpc scenarioNpc = new ScenarioNpc();
                  scenarioNpc.setVId(scenarioNpcVId.incrementAndGet());
                  scenarioNpc.setPlayerId(playerId);
                  scenarioNpc.setScenarioId(juBenDto.juBen_id);
                  scenarioNpc.setLocationId(cityId);
                  scenarioNpc.setForceId(forceId);
                  scenarioNpc.setNpcType(2);
                  scenarioNpc.setArmyId(armyId);
                  Army army = (Army)this.dataGetter.getArmyCache().get(armyId);
                  scenarioNpc.setHp(army.getArmyHp());
                  scenarioNpc.setTacticVal(1);
                  scenarioNpc.setState(0);
                  scenarioNpc.setAddTime(date);
                  snList.add(scenarioNpc);
               }
            }

            this.dataGetter.getScenarioNpcDao().batchCreate(snList);
         }
      } catch (Exception var23) {
         Exception e = var23;
         ErrorSceneLog.getInstance().error("JuBenService.addNpcToCityForNpc catch Exception", e);
      }

   }

   private void addNpcToCityForPlayer(int playerId, int cityId, List<Tuple<Integer, Integer>> list, JuBenDto juBenDto, JuBenCityDto juBenCityDto) {
      try {
         Player player = this.dataGetter.getPlayerDao().read(playerId);
         int forceId = player.getForceId();
         int npcType = true;
         Date date = new Date();
         Builder builder = BuilderFactory.getInstance().getBuilder(18);
         String battleId = NewBattleManager.getBattleId(18, playerId, cityId);
         Battle juBenCityBattle = NewBattleManager.getInstance().getBattleByBatId(battleId);
         boolean state;
         LinkedList snList;
         Tuple general;
         Iterator var16;
         int armyId;
         int num;
         int i;
         ScenarioNpc scenarioNpc;
         Army army;
         if (juBenCityBattle != null) {
            state = true;
            snList = new LinkedList();
            var16 = list.iterator();

            while(var16.hasNext()) {
               general = (Tuple)var16.next();
               armyId = (Integer)general.left;
               num = (Integer)general.right;

               for(i = 0; i < num; ++i) {
                  scenarioNpc = new ScenarioNpc();
                  scenarioNpc.setVId(scenarioNpcVId.incrementAndGet());
                  scenarioNpc.setPlayerId(playerId);
                  scenarioNpc.setScenarioId(juBenDto.juBen_id);
                  scenarioNpc.setLocationId(cityId);
                  scenarioNpc.setForceId(forceId);
                  scenarioNpc.setNpcType(2);
                  scenarioNpc.setArmyId(armyId);
                  army = (Army)this.dataGetter.getArmyCache().get(armyId);
                  scenarioNpc.setHp(army.getArmyHp());
                  scenarioNpc.setTacticVal(1);
                  scenarioNpc.setState(19);
                  scenarioNpc.setAddTime(date);
                  snList.add(scenarioNpc);
               }
            }

            this.dataGetter.getScenarioNpcDao().batchCreate(snList);
            int defForceId = juBenCityBattle.getDefBaseInfo().getForceId();
            int battleSide = true;
            byte battleSide;
            if (defForceId == forceId) {
               battleSide = 0;
            } else {
               battleSide = 1;
            }

            Iterator var30 = snList.iterator();

            while(var30.hasNext()) {
               ScenarioNpc scenarioNpc2 = (ScenarioNpc)var30.next();
               CampArmy tempEACa = builder.copyArmyFromScenarioNpc(this.dataGetter, player, juBenCityBattle, scenarioNpc2, battleSide);
               juBenCityBattle.joinCampArmy(this.dataGetter, battleSide, tempEACa, new int[0]);
            }
         } else if (juBenCityDto.forceId != forceId) {
            state = false;
            snList = new LinkedList();
            var16 = list.iterator();

            while(var16.hasNext()) {
               general = (Tuple)var16.next();
               armyId = (Integer)general.left;
               num = (Integer)general.right;

               for(i = 0; i < num; ++i) {
                  scenarioNpc = new ScenarioNpc();
                  scenarioNpc.setVId(scenarioNpcVId.incrementAndGet());
                  scenarioNpc.setPlayerId(playerId);
                  scenarioNpc.setScenarioId(juBenDto.juBen_id);
                  scenarioNpc.setLocationId(cityId);
                  scenarioNpc.setForceId(forceId);
                  scenarioNpc.setNpcType(2);
                  scenarioNpc.setArmyId(armyId);
                  army = (Army)this.dataGetter.getArmyCache().get(armyId);
                  scenarioNpc.setHp(army.getArmyHp());
                  scenarioNpc.setTacticVal(1);
                  scenarioNpc.setState(0);
                  scenarioNpc.setAddTime(date);
                  snList.add(scenarioNpc);
               }
            }

            this.dataGetter.getScenarioNpcDao().batchCreate(snList);
            Terrain terrain = builder.getTerrain(-1, cityId, this.dataGetter);
            juBenCityBattle = NewBattleManager.getInstance().createBattle(battleId);
            if (juBenCityBattle == null) {
               ErrorSceneLog.getInstance().appendErrorMsg("create battle fail").appendBattleId(battleId).append("playerId", playerId).append("cityId", cityId).append("map size", list.size()).appendClassName("JuBenService").appendMethodName("addNpcToCity").flush();
               return;
            }

            BattleAttacker battleAttacker = new BattleAttacker();
            battleAttacker.attType = 7;
            battleAttacker.attForceId = forceId;
            battleAttacker.attPlayerId = playerId;
            battleAttacker.attPlayer = player;
            juBenCityBattle.init(battleAttacker, 18, cityId, this.dataGetter, false, terrain.getValue());
            builder.dealUniqueStaff(this.dataGetter, juBenCityBattle, -1, cityId);
         } else {
            state = false;
            snList = new LinkedList();
            var16 = list.iterator();

            while(var16.hasNext()) {
               general = (Tuple)var16.next();
               armyId = (Integer)general.left;
               num = (Integer)general.right;

               for(i = 0; i < num; ++i) {
                  scenarioNpc = new ScenarioNpc();
                  scenarioNpc.setVId(scenarioNpcVId.incrementAndGet());
                  scenarioNpc.setPlayerId(playerId);
                  scenarioNpc.setScenarioId(juBenDto.juBen_id);
                  scenarioNpc.setLocationId(cityId);
                  scenarioNpc.setForceId(forceId);
                  scenarioNpc.setNpcType(2);
                  scenarioNpc.setArmyId(armyId);
                  army = (Army)this.dataGetter.getArmyCache().get(armyId);
                  scenarioNpc.setHp(army.getArmyHp());
                  scenarioNpc.setTacticVal(1);
                  scenarioNpc.setState(0);
                  scenarioNpc.setAddTime(date);
                  snList.add(scenarioNpc);
               }
            }

            this.dataGetter.getScenarioNpcDao().batchCreate(snList);
         }
      } catch (Exception var22) {
         Exception e = var22;
         ErrorSceneLog.getInstance().error("JuBenService.addNpcToCityForPlayer catch Exception", e);
      }

   }

   public void removeNpcInCity(int playerId, Integer cityId, int armyId, int num, int camp) {
      long start = System.currentTimeMillis();

      try {
         timerLog.info(LogUtil.formatThreadLog("JuBenService", "removeNpcInCity", 0, 0L, "playerId:" + playerId + "cityId:" + cityId + "armyId:" + armyId + "num:" + num + "camp:" + camp));
         JuBenDto juBenDto = JuBenManager.getInstance().getByPid(playerId);
         if (juBenDto == null) {
            ErrorSceneLog.getInstance().appendErrorMsg("JuBenDto is null").append("playerId", playerId).append("cityId", cityId).append("armyId", armyId).append("num", num).appendClassName("JuBenService").appendMethodName("addNpcToCity").flush();
            return;
         }

         JuBenCityDto juBenCityDto = JuBenManager.getInstance().getJuBenCityDto(playerId, cityId);
         if (juBenCityDto == null) {
            ErrorSceneLog.getInstance().appendErrorMsg("JuBenCityDto is null").append("playerId", playerId).append("cityId", cityId).append("armyId", armyId).append("num", num).appendClassName("JuBenService").appendMethodName("addNpcToCity").flush();
            return;
         }

         int forceId = 0;
         if (camp == 0) {
            Player player = this.dataGetter.getPlayerDao().read(playerId);
            forceId = player.getForceId();
         } else if (camp == 1) {
            forceId = 0;
         } else if (camp >= 101) {
            forceId = camp;
         }

         this.doremoveNpcInCity(playerId, cityId, armyId, num, juBenDto, juBenCityDto, forceId);
         timerLog.info(LogUtil.formatThreadLog("JuBenService", "removeNpcInCity", 2, System.currentTimeMillis() - start, "playerId:" + playerId + "cityId:" + cityId + "armyId:" + armyId + "num:" + num + "camp:" + camp));
      } catch (Exception var12) {
         Exception e = var12;
         ErrorSceneLog.getInstance().error("JuBenService.removeNpcInCity catch Exception", e);
      }

   }

   private void doremoveNpcInCity(int playerId, Integer cityId, int armyId, int num, JuBenDto juBenDto, JuBenCityDto juBenCityDto, int forceId) {
      try {
         String battleId = NewBattleManager.getBattleId(18, playerId, cityId);
         Battle juBenCityBattle = NewBattleManager.getInstance().getBattleByBatId(battleId);
         List CAList;
         LinkedList removeCaList;
         int done;
         if (juBenCityBattle != null) {
            timerLog.info(LogUtil.formatThreadLog("JuBenService", "doremoveNpcInCity", 0, 0L, "playerId:" + playerId + "cityId:" + cityId + "armyId:" + armyId + "num:" + num + "forceId:" + forceId + "battleId:" + battleId));
            CAList = null;
            if (juBenCityBattle.getAttBaseInfo().getForceId() == forceId) {
               CAList = juBenCityBattle.getAttCamp();
            } else {
               if (juBenCityBattle.getDefBaseInfo().getForceId() != forceId) {
                  ErrorSceneLog.getInstance().appendErrorMsg("JuBenService.doremoveNpcInCity battle force error").appendPlayerId(playerId).append("cityId", cityId).append("armyId", armyId).append("juBenCityBattle.getAttBaseInfo().getForceId()", juBenCityBattle.getAttBaseInfo().getForceId()).append("juBenCityBattle.getDefBaseInfo().getForceId()", juBenCityBattle.getDefBaseInfo().getForceId()).flush();
                  return;
               }

               CAList = juBenCityBattle.getDefCamp();
            }

            removeCaList = new LinkedList();
            synchronized(juBenCityBattle.getBattleId()) {
               Iterator var20 = CAList.iterator();

               CampArmy ca;
               while(var20.hasNext()) {
                  ca = (CampArmy)var20.next();
                  if (!ca.isOnQueues() && ca.getGeneralId() == armyId && ca.scenarioArmyType == 2) {
                     removeCaList.add(ca);
                     if (removeCaList.size() >= num) {
                        break;
                     }
                  }
               }

               var20 = removeCaList.iterator();

               while(var20.hasNext()) {
                  ca = (CampArmy)var20.next();
                  CAList.remove(ca);
                  done = this.dataGetter.getScenarioNpcDao().deleteById(ca.getPgmVId());
                  if (done != 1) {
                     ErrorSceneLog.getInstance().appendErrorMsg("JuBenService.doremoveNpcInCity fail when battle").appendPlayerId(playerId).append("cityId", cityId).append("armyId", armyId).append("num", num).appendBattleId(battleId).append("vId", ca.getPgmVId()).flush();
                  }
               }

               return;
            }
         }

         CAList = this.dataGetter.getScenarioNpcDao().getByPlayerIdLocationId(playerId, cityId);
         removeCaList = new LinkedList();
         Iterator var13 = CAList.iterator();

         ScenarioNpc removeSC;
         while(var13.hasNext()) {
            removeSC = (ScenarioNpc)var13.next();
            if (removeSC.getForceId() == forceId && removeSC.getArmyId() == armyId) {
               removeCaList.add(removeSC);
               if (removeCaList.size() >= num) {
                  break;
               }
            }
         }

         var13 = removeCaList.iterator();

         while(var13.hasNext()) {
            removeSC = (ScenarioNpc)var13.next();
            int vId = removeSC.getVId();
            done = this.dataGetter.getScenarioNpcDao().deleteById(vId);
            if (done != 1) {
               ErrorSceneLog.getInstance().appendErrorMsg("JuBenService.doremoveNpcInCity fail when free").appendPlayerId(playerId).append("cityId", cityId).append("armyId", armyId).append("num", num).append("vId", vId).flush();
            }
         }
      } catch (Exception var17) {
         Exception e = var17;
         ErrorSceneLog.getInstance().error("JuBenService.removeNpcInCityOfNpc catch Exception", e);
      }

   }

   public void killAllPlayerPgmsInThisCity(int playerId, int cityId) {
      try {
         JuBenDto juBenDto = JuBenManager.getInstance().getByPid(playerId);
         if (juBenDto == null) {
            ErrorSceneLog.getInstance().appendErrorMsg("JuBenDto is null").append("playerId", playerId).append("cityId", cityId).appendClassName("JuBenService").appendMethodName("killAllPlayerPgmsInThisCity").flush();
            return;
         }

         JuBenCityDto juBenCityDto = JuBenManager.getInstance().getJuBenCityDto(playerId, cityId);
         if (juBenCityDto == null) {
            ErrorSceneLog.getInstance().appendErrorMsg("JuBenCityDto is null").append("playerId", playerId).append("cityId", cityId).appendClassName("JuBenService").appendMethodName("killAllPlayerPgmsInThisCity").flush();
            return;
         }

         Player player = this.dataGetter.getPlayerDao().read(playerId);
         String battleId = NewBattleManager.getBattleId(18, playerId, cityId);
         Battle juBenCityBattle = NewBattleManager.getInstance().getBattleByBatId(battleId);
         if (juBenCityBattle != null) {
            this.clearBattlesInThisCity(player, juBenCityDto, true);
         } else {
            this.dataGetter.getJuBenService().changeForceIdAndState(cityId, 0, 0, playerId, (String)null);
         }

         int capitalId = juBenDto.capital;
         List<PlayerGeneralMilitary> pgmList = this.dataGetter.getPlayerGeneralMilitaryDao().getMilitaryList(playerId);
         Iterator var11 = pgmList.iterator();

         while(var11.hasNext()) {
            PlayerGeneralMilitary pgm = (PlayerGeneralMilitary)var11.next();
            if (pgm.getJubenLoId() == cityId) {
               int done = this.dataGetter.getPlayerGeneralMilitaryDao().upJuBenLocationForceSetState1(pgm.getPlayerId(), pgm.getGeneralId(), capitalId, (double)pgm.getForces(), new Date());
               if (done == 1) {
                  this.dataGetter.getGeneralService().sendGeneralMilitaryRecruitInfo(pgm.getPlayerId(), pgm.getGeneralId());
                  ScenarioEventMessageHelper.sendMoveToCitykMessage(pgm.getPlayerId(), pgm.getGeneralId(), capitalId);
               } else {
                  ErrorSceneLog.getInstance().appendErrorMsg("updateLocationForceSetState1 fail").appendPlayerId(pgm.getPlayerId()).appendGeneralId(pgm.getGeneralId()).append("capitalId", capitalId).append("pgm.getForces().intValue()", pgm.getForces()).appendClassName("JuBenService").appendMethodName("killAllPlayerPgmsInThisCity").flush();
               }
            }
         }

         List<ScenarioNpc> snList = this.dataGetter.getScenarioNpcDao().getByPlayerIdLocationId(playerId, cityId);
         Iterator var17 = snList.iterator();

         while(var17.hasNext()) {
            ScenarioNpc scenarioNpc = (ScenarioNpc)var17.next();
            if (scenarioNpc.getForceId() == player.getForceId()) {
               this.dataGetter.getScenarioNpcDao().deleteById(scenarioNpc.getVId());
            }
         }
      } catch (Exception var13) {
         Exception e = var13;
         ErrorSceneLog.getInstance().error("JuBenService.killAllPlayerPgmsInThisCity catch Exception", e);
      }

   }

   public void killAllNpcsInThisCity(int playerId, int cityId) {
      try {
         JuBenDto juBenDto = JuBenManager.getInstance().getByPid(playerId);
         if (juBenDto == null) {
            ErrorSceneLog.getInstance().appendErrorMsg("JuBenDto is null").append("playerId", playerId).append("cityId", cityId).appendClassName("JuBenService").appendMethodName("killAllPlayerPgmsInThisCity").flush();
            return;
         }

         JuBenCityDto juBenCityDto = JuBenManager.getInstance().getJuBenCityDto(playerId, cityId);
         if (juBenCityDto == null) {
            ErrorSceneLog.getInstance().appendErrorMsg("JuBenCityDto is null").append("playerId", playerId).append("cityId", cityId).appendClassName("JuBenService").appendMethodName("killAllPlayerPgmsInThisCity").flush();
            return;
         }

         Player player = this.dataGetter.getPlayerDao().read(playerId);
         String battleId = NewBattleManager.getBattleId(18, playerId, cityId);
         Battle juBenCityBattle = NewBattleManager.getInstance().getBattleByBatId(battleId);
         if (juBenCityBattle != null) {
            this.clearBattlesInThisCity(player, juBenCityDto, false);
         } else {
            this.dataGetter.getJuBenService().changeForceIdAndState(cityId, player.getForceId(), 0, playerId, (String)null);
         }

         List<ScenarioNpc> snList = this.dataGetter.getScenarioNpcDao().getByPlayerIdLocationId(playerId, cityId);
         Iterator var10 = snList.iterator();

         while(var10.hasNext()) {
            ScenarioNpc scenarioNpc = (ScenarioNpc)var10.next();
            if (scenarioNpc.getForceId() == 0) {
               this.dataGetter.getScenarioNpcDao().deleteById(scenarioNpc.getVId());
            }
         }
      } catch (Exception var11) {
         Exception e = var11;
         ErrorSceneLog.getInstance().error("JuBenService.killAllNpcsInThisCity catch Exception", e);
      }

   }

   public void makeAChoiceToTriggerOperation(int playerId, int eventId) {
      List<ScenarioEvent> list = null;
      JuBenDto dto = JuBenManager.getInstance().getByPid(playerId);
      if (dto != null) {
         list = dto.eventList;
         if (list != null) {
            Iterator var6 = list.iterator();

            while(var6.hasNext()) {
               ScenarioEvent event = (ScenarioEvent)var6.next();
               if (event.getSoloEvent().getId() == eventId) {
                  if (event.getMainChoice() == 0) {
                     return;
                  }

                  ScenarioChoice choice = event.getChoice();
                  if (choice == null) {
                     return;
                  }

                  if (event.getState() != 2) {
                     return;
                  }

                  if (choice.getChoiceCatogery().equalsIgnoreCase("dychoice")) {
                     event.setCurChoice(1);
                  } else {
                     event.setCurChoice(event.getPlayerChoice());
                  }
                  break;
               }
            }

         }
      }
   }

   public int trickReduceForce(int playerId, int cityId, int reduceEach, int num) {
      try {
         Player player = this.dataGetter.getPlayerDao().read(playerId);
         timerLog.info("JuBenService.trickReduceForce start. playerId:" + playerId + "PlayerName:" + player.getPlayerName() + "cityId:" + cityId + "reduceEach:" + reduceEach + "num:" + num);
         JuBenDto juBenDto = JuBenManager.getInstance().getByPid(playerId);
         if (juBenDto == null) {
            ErrorSceneLog.getInstance().appendErrorMsg("JuBenDto is null").append("playerId", playerId).append("cityId", cityId).appendClassName("JuBenService").appendMethodName("trickReduceForce").flush();
            return 0;
         } else {
            JuBenCityDto juBenCityDto = JuBenManager.getInstance().getJuBenCityDto(playerId, cityId);
            if (juBenCityDto == null) {
               ErrorSceneLog.getInstance().appendErrorMsg("JuBenCityDto is null").append("playerId", playerId).append("cityId", cityId).appendClassName("JuBenService").appendMethodName("trickReduceForce").flush();
               return 0;
            } else {
               String battleId = NewBattleManager.getBattleId(18, playerId, cityId);
               Battle juBenCityBattle = NewBattleManager.getInstance().getBattleByBatId(battleId);
               int result = false;
               boolean allonQueue = false;
               int result;
               if (juBenCityBattle != null) {
                  Tuple<Integer, Boolean> tuple = this.trickReduceForceBattle(player, juBenCityBattle, juBenDto, cityId, reduceEach, num);
                  result = (Integer)tuple.left;
                  allonQueue = (Boolean)tuple.right;
               } else {
                  result = this.trickReduceForceFree(player, juBenDto, cityId, reduceEach, num);
               }

               timerLog.info("JuBenService.trickReduceForce end. result:" + result + ", allonQueue:" + allonQueue);
               return result;
            }
         }
      } catch (Exception var13) {
         Exception e = var13;
         ErrorSceneLog.getInstance().error("JuBenService.trickReduceForce catch Exception", e);
         return 0;
      }
   }

   private int trickReduceForceFree(Player player, JuBenDto juBenDto, int cityId, int reduceEach, int num) {
      int reduceSum = 0;
      int reducedCount = 0;
      List<PlayerGeneralMilitary> pgmList = this.dataGetter.getPlayerGeneralMilitaryDao().getMilitaryList(player.getPlayerId());
      Iterator var10 = pgmList.iterator();

      while(var10.hasNext()) {
         PlayerGeneralMilitary pgm = (PlayerGeneralMilitary)var10.next();
         if (pgm.getJubenLoId() == cityId) {
            int reduce = false;
            int reduce;
            if (pgm.getForces() > reduceEach) {
               reduce = reduceEach;
               this.dataGetter.getPlayerGeneralMilitaryDao().consumeForces(pgm.getPlayerId(), pgm.getGeneralId(), (double)reduceEach, new Date());
            } else {
               reduce = pgm.getForces();
               this.dataGetter.getPlayerGeneralMilitaryDao().consumeForces(pgm.getPlayerId(), pgm.getGeneralId(), (double)reduce, new Date());
               this.dataGetter.getPlayerGeneralMilitaryDao().moveJuben(pgm.getPlayerId(), pgm.getGeneralId(), 1, juBenDto.capital);
               ScenarioEventMessageHelper.sendMoveToCitykMessage(pgm.getPlayerId(), pgm.getGeneralId(), juBenDto.capital);
            }

            this.dataGetter.getGeneralService().sendGeneralMilitaryRecruitInfo(pgm.getPlayerId(), pgm.getGeneralId());
            reduceSum += reduce;
            ++reducedCount;
            if (reducedCount >= num) {
               return reduceSum;
            }
         }
      }

      List<ScenarioNpc> snList = this.dataGetter.getScenarioNpcDao().getByPlayerIdLocationId(player.getPlayerId(), cityId);
      Iterator var16 = snList.iterator();

      while(var16.hasNext()) {
         ScenarioNpc scenarioNpc = (ScenarioNpc)var16.next();
         if (scenarioNpc.getForceId() == player.getForceId()) {
            int reduce2 = false;
            int reduce2;
            if (scenarioNpc.getHp() > reduceEach) {
               reduce2 = reduceEach;
               this.dataGetter.getScenarioNpcDao().updateHpAndTacticVal(scenarioNpc.getVId(), scenarioNpc.getHp() - reduceEach, scenarioNpc.getTacticVal());
            } else {
               reduce2 = scenarioNpc.getHp();
               this.dataGetter.getScenarioNpcDao().deleteById(scenarioNpc.getVId());
            }

            reduceSum += reduce2;
            ++reducedCount;
            if (reducedCount >= num) {
               return reduceSum;
            }
         }
      }

      return reduceSum;
   }

   private Tuple<Integer, Boolean> trickReduceForceBattle(Player player, Battle juBenCityBattle, JuBenDto juBenDto, int cityId, int reduceEach, int num) {
      boolean allOnqueue = true;
      int reduceSum = 0;
      synchronized(juBenCityBattle.getBattleId()) {
         List<CampArmy> campList = null;
         LinkedList<CampArmy> deadCampList = new LinkedList();
         BaseInfo baseInfo = null;
         if (juBenCityBattle.getAttBaseInfo().getForceId() == player.getForceId()) {
            campList = juBenCityBattle.getAttCamp();
            baseInfo = juBenCityBattle.getAttBaseInfo();
         } else {
            if (juBenCityBattle.getDefBaseInfo().getForceId() != player.getForceId()) {
               ErrorSceneLog.getInstance().appendErrorMsg("no side is npc").appendBattleId(juBenCityBattle.getBattleId()).append("AttBase forceId", juBenCityBattle.getAttBaseInfo().getForceId()).append("DefBase forceId", juBenCityBattle.getDefBaseInfo().getForceId()).append("cityId", cityId).appendPlayerId(player.getPlayerId()).appendPlayerName(player.getPlayerName()).appendClassName("JuBenService").appendMethodName("trickReduceForceBattle").flush();
               return null;
            }

            campList = juBenCityBattle.getDefCamp();
            baseInfo = juBenCityBattle.getDefBaseInfo();
         }

         int remainder = reduceEach % 3;
         reduceEach -= remainder;
         int reducedCount = 0;
         Iterator var16 = campList.iterator();

         CampArmy temp;
         label75:
         do {
            do {
               if (!var16.hasNext()) {
                  break label75;
               }

               temp = (CampArmy)var16.next();
            } while(temp.isOnQueues());

            allOnqueue = false;
            int reduce = false;
            int reduce;
            if (temp.getArmyHp() > reduceEach) {
               reduce = reduceEach;
               if (temp.scenarioArmyType == 0 && temp.getPlayerId() > 0) {
                  this.dataGetter.getPlayerGeneralMilitaryDao().consumeForces(temp.getPlayerId(), temp.getGeneralId(), (double)reduceEach, new Date());
                  this.dataGetter.getGeneralService().sendGeneralMilitaryRecruitInfo(temp.getPlayerId(), temp.getGeneralId());
               } else {
                  this.dataGetter.getScenarioNpcDao().updateHpAndTacticVal(temp.getPgmVId(), temp.getArmyHp() - reduceEach, temp.getTacticVal());
               }
            } else {
               reduce = temp.getArmyHp();
               if (temp.scenarioArmyType == 0 && temp.getPlayerId() > 0) {
                  this.dataGetter.getPlayerGeneralMilitaryDao().consumeForces(temp.getPlayerId(), temp.getGeneralId(), (double)reduce, new Date());
                  this.dataGetter.getPlayerGeneralMilitaryDao().moveJuben(temp.getPlayerId(), temp.getGeneralId(), 1, juBenDto.capital);
                  ScenarioEventMessageHelper.sendMoveToCitykMessage(temp.getPlayerId(), temp.getGeneralId(), juBenDto.capital);
                  this.dataGetter.getGeneralService().sendGeneralMilitaryRecruitInfo(temp.getPlayerId(), temp.getGeneralId());
               } else {
                  this.dataGetter.getScenarioNpcDao().deleteById(temp.getPgmVId());
               }

               deadCampList.add(temp);
            }

            temp.setArmyHp(temp.getArmyHp() - reduce);
            temp.setArmyHpLoss(temp.getArmyHpLoss() + reduce);
            if (baseInfo.getNum() < reduce) {
               ErrorSceneLog.getInstance().appendErrorMsg("兵力小于0,JuBenService 3699行");
            }

            if (baseInfo.getNum() < reduce) {
               ErrorSceneLog.getInstance().appendErrorMsg("兵力小于0 jubenservice 3703行");
            }

            baseInfo.setNum(baseInfo.getNum() - reduce);
            reduceSum += reduce;
            ++reducedCount;
         } while(reducedCount < num);

         var16 = deadCampList.iterator();

         while(true) {
            if (!var16.hasNext()) {
               break;
            }

            temp = (CampArmy)var16.next();
            campList.remove(temp);
         }
      }

      Tuple<Integer, Boolean> resultTuple = new Tuple();
      resultTuple.left = reduceSum;
      resultTuple.right = allOnqueue;
      return resultTuple;
   }

   public ScenarioEvent getEventByCityId(int playerId, int cityId) {
      JuBenDto dto = JuBenManager.getInstance().getByPid(playerId);
      if (dto != null && dto.eventList != null) {
         Iterator var5 = dto.eventList.iterator();

         while(var5.hasNext()) {
            ScenarioEvent event = (ScenarioEvent)var5.next();
            if (event != null && event.getMainChoice() != 0 && event.getPlayerChoice() != 0) {
               ScenarioChoice choice = event.getChoice();
               if (choice != null) {
                  int choiceCity = choice.getChoiceCity();
                  if (choiceCity == cityId && event.getState() < 3) {
                     return event;
                  }
               }
            }
         }

         return null;
      } else {
         return null;
      }
   }

   public void setJubenBuff(int playerId, double value, long duration, int type) {
      try {
         if (type != 1 && type != 2) {
            ErrorSceneLog.getInstance().appendErrorMsg("type is invalid").appendPlayerId(playerId).append("type", type).appendClassName("JuBenService").appendMethodName("setJubenPlayerBuff").flush();
            return;
         }

         JuBenDto juBenDto = JuBenManager.getInstance().getByPid(playerId);
         if (juBenDto == null) {
            ErrorSceneLog.getInstance().appendErrorMsg("juBenDto is null").appendPlayerId(playerId).appendClassName("JuBenService").appendMethodName("setJubenPlayerBuff").flush();
            return;
         }

         if (duration == 0L) {
            duration = 0L;
         } else {
            duration += System.currentTimeMillis();
         }

         if (type == 1) {
            juBenDto.juben_buff_player = value;
            juBenDto.juben_buff_player_duration_time = duration;
         } else {
            if (type != 2) {
               return;
            }

            juBenDto.juben_buff_npc = value;
            juBenDto.juben_buff_npc_duration_time = duration;
         }
      } catch (Exception var8) {
         Exception e = var8;
         ErrorSceneLog.getInstance().error("JuBenService.setJubenPlayerBuff catch Exception", e);
      }

   }

   public void setJubenAttDefBaseBuff(int playerId, int attBase, int defBase, long duration, int type) {
      try {
         if (type != 1 && type != 2) {
            ErrorSceneLog.getInstance().appendErrorMsg("type is invalid").appendPlayerId(playerId).append("type", type).appendClassName("JuBenService").appendMethodName("setJubenAttDefBaseBuff").flush();
            return;
         }

         if (attBase <= 0 && defBase <= 0) {
            ErrorSceneLog.getInstance().appendErrorMsg("attBase or defBase is invalid").appendPlayerId(playerId).append("attBase", attBase).append("defBase", defBase).appendClassName("JuBenService").appendMethodName("setJubenAttDefBaseBuff").flush();
            return;
         }

         JuBenDto juBenDto = JuBenManager.getInstance().getByPid(playerId);
         if (juBenDto == null) {
            ErrorSceneLog.getInstance().appendErrorMsg("juBenDto is null").appendPlayerId(playerId).appendClassName("JuBenService").appendMethodName("setJubenAttDefBaseBuff").flush();
            return;
         }

         if (duration == 0L) {
            duration = 0L;
         } else {
            duration += System.currentTimeMillis();
         }

         if (type == 1) {
            juBenDto.juben_att_base_buff_player = attBase;
            juBenDto.juben_def_base_buff_player = defBase;
            juBenDto.juben_att_def_base_buff_player_duration_time = duration;
         } else {
            if (type != 2) {
               return;
            }

            juBenDto.juben_att_base_buff_npc = attBase;
            juBenDto.juben_def_base_buff_npc = defBase;
            juBenDto.juben_att_def_base_buff_npc_duration_time = duration;
         }
      } catch (Exception var8) {
         Exception e = var8;
         ErrorSceneLog.getInstance().error("JuBenService.setJubenPlayerBuff catch Exception", e);
      }

   }

   public void initScenarioNpcVid() {
      scenarioNpcVId.set(this.dataGetter.getScenarioNpcDao().getMaxVid());
   }

   public void checkRoyalJadeRobbed(Battle bat) {
      if (bat != null) {
         try {
            CampArmy army = ((BattleArmy)bat.getAttList().get(0)).getCampArmy();
            if (army.getPlayerId() <= 0) {
               return;
            }

            JuBenDto dto = JuBenManager.getInstance().getByPid(army.getPlayerId());
            if (dto == null || dto.royalJadeBelong <= 0) {
               return;
            }

            int defForceId = bat.getDefBaseInfo().getForceId();
            Integer capitalId = (Integer)JubenConstans.map.get(defForceId);
            if (capitalId == null) {
               return;
            }

            int cityId = bat.getDefBaseInfo().getId();
            if (capitalId != cityId) {
               return;
            }

            SoloCity soloCity = (SoloCity)this.soloCityCache.get(cityId);
            if (soloCity == null) {
               return;
            }

            if (dto.royalJadeBelong != soloCity.getBelong()) {
               return;
            }

            transferRoyalJade(dto, 0);
         } catch (Exception var8) {
            Exception e = var8;
            errorLog.error(this, e);
         }

      }
   }

   public void checkJadeTimeOver(JuBenDto dto) {
      try {
         if (dto == null || dto.juBen_id != 10) {
            return;
         }

         long now = System.currentTimeMillis();
         if (dto.royalJadeBelong != 0 && now >= dto.royalEndTime && dto.royalJadeBelong != -1) {
            ScenarioEventJsonBuilder.sendDialog(dto.player_id, 10006, JubenConstans.forceId2NameMap.get(dto.royalJadeBelong));
            this.juBenOver(dto.player_id, dto, false);
         }
      } catch (Exception var4) {
         Exception e = var4;
         errorLog.error(this, e);
      }

   }

   public void checkWorldDramaOpen(int playerId, int playerLv, boolean isGm) {
      try {
         if (playerLv == this.dataGetter.getWdSjpDramaCache().getMinWorldDramaLv()) {
            CityEventManager.getInstance().addPlayerEvent(playerId, 5);
            CityEventManager.getInstance().bobaoOnePlayerEvent(playerId, 5);
         }
      } catch (Exception var5) {
         Exception e = var5;
         errorLog.error(this, e);
      }

   }

   public OperationResult enterWorldDramaScene(PlayerDto playerDto, int sId, Integer grade) {
      try {
         int playerId = playerDto.playerId;
         JuBenDto juBenDto = JuBenManager.getInstance().getByPid(playerId);
         if (juBenDto != null) {
            return new OperationResult(false, "");
         } else {
            PlayerScenario ps = this.playerScenarioDao.getScenarioByPidSid(playerId, sId);
            if (ps == null) {
               WdSjpDrama drama = this.dataGetter.getWdSjpDramaCache().getWorldDramaByDramaIdAndGrade(sId, grade);
               boolean open = false;
               if (drama != null) {
                  int techId = drama.getOpenTech();
                  PlayerTech playerTech = this.dataGetter.getPlayerTechDao().getPlayerTech(playerId, techId);
                  if (playerTech.getStatus() >= 5) {
                     open = this.openNextJuBen(playerId, sId);
                  }
               }

               if (!open) {
                  return new OperationResult(false, LocalMessages.T_COMM_10020);
               }

               ps = this.playerScenarioDao.getScenarioByPidSid(playerId, sId);
            }

            if (ps.getState() != 0) {
               return new OperationResult(false, LocalMessages.JUBEN_CANNOT_JOIN);
            } else {
               List<PlayerGeneralMilitary> pgmList = this.playerGeneralMilitaryDao.getMilitaryList(playerId);
               int jubenLoId = 0;
               Map<Integer, SoloCity> map = this.soloCityCache.getBySoloId(sId);
               Iterator var11 = map.values().iterator();

               while(var11.hasNext()) {
                  SoloCity sc = (SoloCity)var11.next();
                  if (sc.getCapital() == 1 && sc.getBelong() == 0) {
                     jubenLoId = sc.getId();
                  }
               }

               int locationId = (Integer)WorldCityCommon.nationMainCityIdMap.get(playerDto.forceId);
               int res = this.playerGeneralMilitaryDao.updateJuBenLocation(playerDto.playerId, locationId, jubenLoId);
               if (res != pgmList.size()) {
                  return new OperationResult(false, LocalMessages.JUBEN_CANNT_JOIN_GENREAL_BUSY);
               } else {
                  this.updateJuBen(playerId, sId, grade);
                  this.initJuBenNpcs(playerDto, sId, grade);
                  this.generalService.sendGeneralMilitaryList(playerId);
                  JsonDocument doc1 = new JsonDocument();
                  doc1.startObject();
                  doc1.createElement("inJuBen", true);
                  doc1.endObject();
                  Players.push(playerId, PushCommand.PUSH_UPDATE, doc1.toByte());
                  this.cacheJuBen(playerId, sId);
                  return new OperationResult(true);
               }
            }
         }
      } catch (Exception var13) {
         Exception e = var13;
         errorLog.error(this, e);
         return new OperationResult(false, LocalMessages.T_COMM_10011);
      }
   }

   public boolean isInWorldDrama(int playerId) {
      JuBenDto dto = JuBenManager.getInstance().getByPid(playerId);
      return dto != null && this.isWorldDrama(dto.juBen_id);
   }
}
